      PROGRAM SEIS3 
C      VERSION F77 1.0 OS/2 
C                       SEISRISK III   
C   
C      COMPUTER PROGRAM FOR DETERMINING GROUND MOTIONS   
C          FOR USE IN SEISMIC HAZARD MAPPING   
C   
C      ******ALLOWS LOCATIONS OF FUTURE EARTHQUAKES IN SEISMIC   
C         SOURCE ZONES TO HAVE A NORMAL DISTRIBUTION*******   
C   
C      SEISRISK III IS A REVISION OF SEISRISK II, DOCUMENTED IN OPEN    
C         FILE REPORT 82-293.   
C   
C       SEE MODEL DESCRIPTION OF SEISRISK III AND ADDITIONAL   
C          DOCUMENTATION IN USGS BULLETIN 1772   
C   
C      FILES:   
C         FILE 15:  INPUTS   
C         FILE 16:  OUTPUTS   
C         FILE 02:  SUMMARY FOR PLOTS--SEE TEXT   
C         FILE 03:  ACCELERATIONS SAVED ON FILE 03 FOR USE IN NEXT   
C                   RUN IF NEXT RUN IS A CONTINUATION   
C   
C                           INPUTS   
C   
C  1. TITLE-UP TO 80 CHARACTERS   (FREE FIELD)   
C  2. ISW, SIGMAX   (FREE FIELD)   
C       ISW=0 NEW RUN (USUAL CASE)  ISW=1 RESTART OR CONTINUE   
C             FROM PREVIOUS RUN   
C       SIGMAX=MAXIMUM STANDARD DEVIATION (KM) FOR EARTHQUAKE   
C             LOCATION VARIABILITY IN SEISMIC SOURCE ZONES FOR   
C             THIS RUN.   
C  3. PROB,NTIMS, JTIM(1),JTIM(2)....JTIM(NTIMS)   
C    ACCELERATION IS SOUGHT FOR WHICH THERE IS PROBABILITY PROB OF   
C    NOT BEING EXCEEDED IN JTIM(1), JTIM(2), ...JTIM(NTIM)   
C    YEARS   
C    PROB = EXTREME PROBABILITY IN DECIMAL   
C    NTIMS = NUMBER OF TIMES FOR WHICH CALCULATION IS DONE   
C    JTIM(I)  =  DURATIONS  (YEARS) FOR WHICH EXTREME MOTIONS ARE TO BE   
C            CALCULATED AT THE PROB PROBABILITY LEVEL, 1 <= I <= NTIMS   
C  4. SCALE, DSW, SD, INOS  (FREE FIELD)   
C        SCALE=SCALING FACTOR FOR GROUND MOTION BOXES   
C        SCALE=1 FOR MOTIONS .02 TO 1.0--SCALE ACCORDINGLY   
C        DSW:  =1 IF INPUTS ARE DEGREES AND MINUTES   
C              =0 IF INPUTS ARE DECIMAL DEGREES   
C        SD=STANDARD DEVIATION IN LOG ACCELERATION   
C             FOR ACCELERATION VARIABILITY AROUND MEAN VALUE   
C        INOS=1: DIVIDE MAGNITUDE INTERVAL IN HALF AND DO CALCULATIONS   
C             AT TWICE AS MANY MAGNITUDES (ASSUMES GUTENBERG-RICHTER   
C             B-VALUE IS SAME FOR ALL INTERVALS.)   
C        INOS= ANY NUMBER OTHER THAN 1: DO CALCULATIONS FOR ORIGINAL   
C             MAGNITUDE INTERVALS   
C  5. X1,Y1, X2,Y2 (LONG,LAT) IN DECIMAL DEGREES (FREE FIELD)   
C     TRANSFORM GREAT CIRCLE THRU (X1,Y1), (X2,Y2), (0,0)   
C     TO EQUATOR FOR NEW COORDIATE SYSTEM   
C  6. FL1,PH1,FL2,PH2,PHINC   
C     (FL1,PH1) UPPER LEFT    (FL2,PH2) LOWER RIGHT  (LONG, LAT)   
C     CORNERS OF SEISMIC FELT REGION FOR RISK COMPUTATION   
C     RECTANGULAR REGION WITH SIDES PARALLEL TO ARC   
C     OF GREAT CIRCLE THRU (X1,Y1), (X2,Y2) (0,0) --DEFINED BY 5.   
C     OTHER TWO SIDES PERPENDICULAR AND THRU GIVEN END POINTS   
C   
C         + (FL1,PH1)   
C        1     .   
C     (X1,Y1) 1     .   
C    .             1     .   
C        .              1     .   
C            .               1     .   
C                .       .        1   
C           (FL2,PH2)+        (X2,Y2)   
C   
C   
C     AREA WITHIN DOTS REPRESENTS FELT REGION   
C    '1' S REPRESENTS LINE JOINING (X1,Y1) (X2,Y2)   
C    PHINC (LONG,LAT) INCREMENT IN DEGREES (IN NEW COORDINATE   
C       SYSTEM) FOR WHICH RISK IS TO BE COMPUTED   
C   
C  7. IROW1, IROW2, ICOL1, ICOL2   (FREE FIELD)   
C        STARTING AND ENDING ROWS AND COLUMNS FOR THIS RUN   
C        ACCELERATIONS COMPUTED FOR SITES IN THESE ROWS   
C        AND COLUMNS--MAY BE SUBSET OF SEISMIC FELT REGION DEFINED   
C        IN INPUT 6.   ALSO IROW1=IROW2=ICOL1=ICOL2=0 PERMITTED   
C        IF ONLY INDIVIDUAL SITES ON LINES (INPUT 8) ARE SELECTED.   
C  8. INDV (FREE FIELD)   
C        NUMBER OF LINE SEGMENTS CONTAINING INDIVIDUAL SITES AT   
C        WHICH ACCELERATION IS TO BE COMPUTED; ZERO IF   
C        ONLY FIXED GRID IS USED.   
C    IF INDV > 0 READ NEXT INPUTS, OTHERWISE SKIP TO INPUT 9.   
C     NVS (FREE FIELD)   
C       NUMBER OF SITES PER LINE SEGMENT   
C     XE1,YE1,XE2,YE2 (FREE FIELD--INDV LINES, ONE PAIR PER LINE)   
C       END POINTS (LONG, LAT) OF LINE SEGMENT:  SITES WILL BE   
C       EVENLY SPACED ON LINE IN NEW COORDINATE SYSTEM   
C    NOTE: NO SMOOTHING OF ACCELERATIONS AT SITES ON LINE FOR   
C    ACCELERATIONS FROM EARTHQUAKES WITHIN AREAL SOURCE ZONES.   
C    CALCULATIONS FOR UNIFORM SEISMICITY ONLY AT THESE SITES.   
C  9. JENT,MDIS (FREE FIELD)   
C      JENT=NO OF MAGNITUDES FOR WHICH ACCELERATION IS   
C         TABULATED AS A FUNCTION OF DISTANCE   (MAXIMUM 8)   
C      MDIS=NUMBER OF DISTANCES IN ATTENUATION TABLE (MAXIMUM 20)   
C  10. NAM, TM (JENT VALUES OF TM)   
C      NAM=IDENTIFIER UP TO 10 CHARACTERS-FOR EXAMPLE 'SCHN-SEED'   
C         IDENTIFIES ATTENUATION CURVES USED   
C      TM=MAGNITUDE FOR WHICH TABLE OF DISTANCE VERSUS ACCELERATION   
C         VALUES FOLLOWS  (FREE FIELD)   
C   *******MAGNITUDES MUST BE IN DESCENDING ORDER***   
C  11. RTAB(I), (ATAB(I,J),J=1,JENT)   (MDIS LINES, I=1,MDIS)   
C     RTAB(I)=ITH TABULAR DISTANCE IN KILOMETERS FROM EARTHQUAKE SOURCE   
C     ATAB(I,J)=MEAN PEAK ACCELERATION (OR OTHER GROUND MOTION PARAMETER   
C              AT I TH DISTANCE FOR J TH MAGNITUDE.   
C   
C   
C    SOURCE AREA INPUTS:   
C   
C    EACH SOURCE DECK - -   
C  1S. NUM, YRNOC, IPRINT, TOTL, DUMID, ALS, BLS, SIGLS   
C    FORMAT(I2, F10.0, I2, F10.0, A4, 2F6.2, F5.2)   
C    NUM=0 FOR SEISMIC SOURCE AREAS IF NO AVERAGING FOR EARTHQUAKE   
C          LOCATION UNCERTAINTY IS TO BE DONE AT END OF GROUND   
C          MOTION COMPUTATIONS FOR THIS SOURCE ZONE   
C     NUM=98 FOR SEISMIC SOURCE ZONES IF AVERAGING FOR EARTHQUAKE   
C           LOCATION UNCERTAINTY IS TO BE DONE AT END OF COMPUTATIONS   
C           FOR THIS SOURCE ZONE   
C        =99 FOR 1ST FAULT SET   
C        =0 FOR ALL FAULT SETS AFTER 1ST   
C        =99 AT END OF COMPUTATION   
C    YRNOC=NUMBER OF YEARS OVER WHICH THE EARTHQUAKE OCCURRENCES   
C              TAKE PLACE   
C    IPRINT = -1  NO STATISTICS FOR THIS (INTERMEDIATE) SET OF   
C                OCCURRENCES   
C           =1 STATISTICAL CALCULATIONS AND PRINTOUT (ON UNIT 16)   
C           =2 SAME AS=1 PLUS SUMMARY FILE FOR PLOT, ETC (UNIT 2)   
C           =3 OMIT PRINTOUT; DO SUMMARY FILE FOR PLOT (UNIT 2)   
C   TOTL IGNORED HERE BUT USED FOR FAULTS   
C   DUMID = FOUR CHARACTER IDENTIFIER FOR SOURCE ZONE OR FAULT   
C   ALS=EARTHQUAKE LOCATION UNCERTAINTY STANDARD DEVIATION IN KM;   
C       CURRENT VALUE OF ALS IS IGNORED WHEN NUM=0   
C   BLS, SIGLS IGNORED HERE BUT USED FOR FAULTS   
C   
C  2S. JSEG,IFR,ITOT   
C   JSEG=NUM OF PAIRS OF QUADRILATERSL CORNER POINTS IN THIS SOURCE   
C       SET (JSEG-1 QUADS).   
C   SEISMICITY TO BE APPORTIONED BY FRACTIONAL AREA AMONG ITOT SOURCES.   
C    IFR  = SET NUMBER (IFR =1,2...ITOT IN SEQUENCE)   
C    ITOT=10 MAX;    TOTAL QUAD PAIRS FOR ITOT SOURCES MAXIMUM 50   
C  3S. JSEG QUADRILATERAL ENDPOINT LINES (TWO POINTS PER LINE):   
C    QUAD CORNER POINTS (LEFT LONG, LEFT LAT), (RIGHT LONG, RIGHT LAT),   
C    IN DECIMAL DEGREES (IF DSW=0)  DEGREES, MINUTES (IF DSW=1)   
C   
C     X1,Y1 ____________ X2,Y2   
C          1           1   
C          1           1   
C          1           1   
C          1           1   
C     X3,Y3 ____________ X4,Y4   
C           1           1   
C            1           1   
C             1           1   
C              1           1   
C               1___________1   
C         X5,Y5              X6,Y6   
C   
C   JSEG=3 IN THIS EXAMPLE:  QUAD ENDPOINT PAIRS ARE   
C                (X1,Y1)---(X2,Y2)   
C                (X3,Y3)---(X4,Y4)   
C                (X5,Y5)---(X6,Y6)   
C    SUBREGIONS OF A SET ARE DEFINED AS SHOWN   
C    SUBREGIONS OF ONE SET ARE SEPARATE FROM THOSE OF OTHER SETS   
C    REPEAT 2S, 3S FOR ITOT SOURCES   
C  4S. NOC(L)  L=1,LEV  (LEV=12F6.2)   (LEV=12 MAXIMUM)   
C    NUMBERS OF EVENTS EXPECTED IN YRNOC YEARS IN EACH   
C          MAGNITUDE INTERVAL FOR EARTHQUAKE OCCURRENCES   
C  5S. FM(L), L=1,LEV  (12F6.2)   
C    FM(L)=CENTER OF MAGNITUDE INTERVAL FOR WHICH NOC(L) OCCUR   
C   
C     REPEAT 1S. THRU 5S. FOR REMAINING SOURCES   
C   
C        FAULT INPUTS:   
C   
C  1F.  NUM, YRNOC, IPRINT, TOTL, DUMID, ALS, BLS, SIGLS   
C    PARAMETERS DEFINED AS IN 1S. ABOVE   
C  **NOTE NUM=99 FOR FIRST FAULT, =0 THEREAFTER FOR SUCCESSIVE FAULTS   
C    ALS,BLS,SIGLS RUPTURE LENGTH PARAMETERS   
C    IF ALS, BLS NON ZERO:   
C        LENGTH=10**(ALS +BLS*M +FR*SIGL)   
C        WHERE M=MAGNITUDE;   SIGL=STANDARD DEVIATION (IN LOG LENGTH)   
C    FR=(NORMALLY) 5 VALUES IN RANGE (-2,+2)  IF SIGL NON ZERO   
C    FR=0 (1 VALUE)--MEAN RUPTURE LENGTH ONLY IF SIGL=0   
C    IF ALS,BLS,SIGLS=0 (OR BLANK) PREVIOUS VALUES ARE USED   
C    IF NO PREVIOUS VALUES INPUT, DEFAULT VALUES ARE USED:   
C        ALS=-1.085    BLS=.389   SIGLS=.52   
C    TOTL=DISTANCE BETWEEN FAULTS IF THIS SET OF FAULTS IS A SET   
C         OF "DUMMY" FAULTS  USED TO APPROXIMATE A UNIFORM FIELD    
C         OF FAULTS.   
C     TOTL=0 IF INDIVIDUAL FAULT OR A NUMBER OF WELL DEFINED FAULTS    
C         ARE USED.   
C     TOTL DETERMINES WHETHER GROUND MOTIONS FOR A SITE ARE TO   
C         BE SMOOTHED IN DISTANCE OR SMOOTHED IN MAGNITUDE   
C         (SMOOTHED IN MAGNITUDE IF TOTL=0)   
C         (SMOOTHED IN DISTANCE (TOTL NONZERO).   
C 2F. JSEG, IFR, ITOT  (FREE FIELD)   
C    JSEG=NUM OF FAULT SEGMENT END POINTS TO BE CONNECTED   
C        INTO SINGLE FAULT   (JSEG-1 SEGMENTS)   
C    IFR, ITOT AS DEFINED IN 2S   
C 3F. (XL(I,I(FR),YL(I,I(FR), I=1,JSEG)   (FREE FIELD)   
C       XL=LONG  YL=LAT (DEGREES)  (IFR=FAULT NUMBER)   
C     JSEG=24 MAX        ITOT=26 MAX   
C 4F. NOC(L)   SAME AS IN 4S.   
C 5F. FM(L) SAME AS 5S.   
C    REPEAT 2F, 3F FOR ITOT FAULTS   
C   
C    REPEAT 1F. THRU 5F. FOR REMAINING FAULTS   
C   
C    END WITH NUM=99 (OMIT OTHER INPUTS ON LINE)   
C * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *   
C     DECLARE  
      PARAMETER (MAXAR=1601) 
      CHARACTER  IDSW*16, NAM*10,TYTLE*80,DUMID*4   
      REAL FAC(0:2500)   
      DIMENSION IDSW(2),IBR(10),DTOT(26)   
      DIMENSION XPT2(500),YPT2(500),XPT1(500),YPT1(500)   
      DIMENSION PRLS(10),RLLS(10,25)   
      DIMENSION NRLSV(25),PRLRL(10,25),RLL(10,25)   
      DIMENSION DISL(50),ANGL(50)   
      COMMON/ATA/ATA(20,25)   
      COMMON/INOUT/MDUM(4),STSIZE,DUM1   
      COMMON/SLINDS/SLD1(4),PERPA(4),SLD2(4),SLLQ(4),   
     + MINA(4),PERPAQ(4),SLDUM2(8)   
      COMMON/EXTRA/ISID,SHDIS,DISTL(24),INEAR   
      COMMON /XLYL/XLL(4),YL(4),XR(4),YR(4),XC(4),YC(4)   
      COMMON/ITABS/DTAB(105,25),MAXA(25)   
      COMMON/MAGDIS/JENT,MDIS   
      DIMENSION TMDIF(10),ATAB(20,25),TM(10),ATADIF(20,25)   
      COMMON/RTB/RTAB(20)   
      COMMON/XYAREA/XSAV(2,50),YSAV(2,50),SAREA(50)   
C*******NEED MAXDIM=DIMENSION OF REG & OF RAWBIN(MAXDIM,MAXAR)   
      DIMENSION REGG(MAXAR)   
      DIMENSION REG(55),RAWBIN(55,MAXAR), SMOBIN(55,MAXAR)   
      COMMON/RDIS/RDIS   
      COMMON/WDS/MAX,MAXP,MAXSP   
      COMMON/EXT/PROB,EX,EXL   
      COMMON/TIMS/FTIM(20),JTIM(20),NTIMS,NWT,IPRINT   
C*** ISCOM = DIMENSION OF FOLLOWING SIN,COS ARRAYS   
      COMMON/SINCOS/SINX(500),COSX(500),SINY(500),COSY(500)   
      COMMON/QUAD/MAXQ,AC(105),DUMLOG,ACLOG(105)   
      DIMENSION X(4),Y(4),NOC(24),FM(25)   
      COMMON/LINPS/DIST(24,26),DISQ(24,26),JSEG,JSEGM,   
     + XL(24,26),YP(24,26),COA(24,26),SIA(24,26)   
      COMMON/LINDIS/DLS(24),PERP(24),MIN(24),PERSQ(24)   
      DIMENSION JM(26), DISREM(24)   
      COMMON/ACCEL/GM(25),EXDIF(101),ATAH(20,25),ACLIM(2)   
C ARRAYS ON PREVIOUS LINE INSERTED FOR SPREADING OUT ACCELERATIONS   
      REAL NOC   
      INTEGER DSW   
      CHARACTER*60 FILE15, FILE16, FILE02, FILE03  
      DATA ISCOM/500/   
      DATA MAXDIM/55/   
      DATA FAC(0)/1./  
      DATA IMAXSQ/400/   
      DATA LINSET,LINE,NRLS/0,0,0/   
      DATA IDSW/'DECIMAL DEGREES ','DEGREES, MINUTES'/   
      DATA R,PI2,PI/6378.,6.2831854,3.1415927/   
C     EXECUTE  
      PRINT *, 'ENTER INPUT FILE NAME  '  
      READ(*,1002) FILE15  
      PRINT *, 'ENTER OUTPUT FILE NAME  '  
      READ(*,1002) FILE16  
      PRINT *, 'ENTER AUXILLIARY FILE NAME 02  '  
      READ(*,1002) FILE02  
      PRINT *, 'ENTER AUXILLIARY FILE NAME 03  '  
      READ(*,1002) FILE03  
      OPEN(15,FILE=FILE15,STATUS='OLD')   
      OPEN(16,FILE=FILE16,STATUS='UNKNOWN')   
      OPEN(2,FILE=FILE02,STATUS='UNKNOWN',FORM='UNFORMATTED')   
      OPEN(3,FILE=FILE03,STATUS='UNKNOWN',FORM='UNFORMATTED')              
 1002 FORMAT(A60)  
C     INPUT ON UNIT 15   
      REWIND 15   
C     SAVED ON UNIT 3 FOR LATER USE OR CONTINUATION   
      REWIND 3   
      RAD=PI/180.   
      ALLERR=0.   
      DLEVSV=0.   
      FLEVST=0.   
      LEVNO=0.   
      TOT5=0.   
      READ(15,20) TYTLE   
   20 FORMAT(A80)   
      WRITE(16,30) TYTLE   
   30 FORMAT('',A80)   
C  ISW TELLS WHETHER TO INCLUDE DATA FROM A PREVIOUS RUN, ZERO IF NO.   
C  SIGMAX=MAXIMUM VALUE OF SIGMA (KM, IN EARTHQUAKE LOCATION)   
      READ(15,*)ISW,SIGMAX   
      IF(ISW.EQ.0) WRITE(16,40)   
   40 FORMAT(' ISW=0: NEW RUN--NO PREVIOUS RESULTS INCLUDED')   
      IF(ISW.EQ.1) WRITE (16,50)   
   50 FORMAT(' ISW=1: RUN CONTINUATION; ADD TO PREVIOUS RESULTS')   
      IF(ISW.EQ.0) GO TO 70   
      IDRC=1   
   60 READ(3,END=70) (SMOBIN(IQRP,IDRC),IQRP=1,MAXDIM)   
      IDRC=IDRC+1   
      GO TO 60   
   70 REWIND 3   
C    PROB=EXTREME PROBABILITY IN DECIMAL   
C    NTIMS ARE NUMBER OF 'JTIMS' FOR WHICH CALCULATION IS DONE   
C    JTIMS ARE THE DURATIONS FOR WHICH THE EXTREME MOTIONS ARE   
C    TO BE CALCULATED AT THE PROB EXTREME PROBABILITY LEVEL   
      READ (15,*) PROB, NTIMS, (JTIM(JV),JV=1,NTIMS)   
      IF (PROB.LT.1.) GO TO 90   
      WRITE(16,80) PROB   
   80 FORMAT(' PROB =',F8.3,' MUST BE DECIMAL LESS THAN ONE')   
      STOP 5555  
   90 CONTINUE   
      WRITE (16,100) PROB,(JTIM(JV),JV=1,NTIMS)   
  100 FORMAT(' EXTREME PROBABILITY ',F6.3   
     +/'   FOR EXPOSURE TIMES (YEARS) ',2(10I5/))   
      EX=-ALOG(PROB)   
      EXL=ALOG(EX)   
      DO 110 JV=1,NTIMS   
  110 FTIM(JV)=JTIM(JV)   
C   
      READ(15,*) SCALE,DSW,SD,INOS   
      WRITE(16,120) SCALE,IDSW(DSW+1),IDSW(DSW+1),SD   
  120 FORMAT(' SCALE FACTOR FOR GROUND MOTION "BOX" LEVELS=',   
     +F7.2/' COORDINATES INPUT IN ' ,A16,   
     +/'    COORDINATES ARE PRINTED IN ',A16,   
     +/' VARIABILITY IN ATTENUATION, SIGMA=',F6.2)   
C      SCALE=MULTIPLICATIVE FACTOR FOR ACCELERATION LEVELS   
C      DSW=0 IF INPUT IS DECIMAL DEGREES; =1 FOR DEGREES,MINUTES   
C      SD=STANDARD DEVIATION FOR LOG ACCELERATION   
C   READ (X1,Y1), (X2,Y2) =LONG,LAT IN DEC. DEGREES OF 2 POINTS   
C   TO TRANSFORM TO EQUATOR   
C      (X1,Y1) TO (0.,0)(X2,Y2) TO (DIST. BETWEEN POINTS,0)   
  130 READ(15,*) X1,Y1,X2,Y2   
      WRITE (16,140) X1,Y1,X2,Y2   
  140 FORMAT(' GRID ORIENTED PARALLEL TO GREAT CIRCLE THRU (',   
     + F7.2,',',F6.2,'),(',F7.2,',',F6.2,')')   
C  CONVERT TO DECIMAL DEGREES UNLESS DSW=0.   
      IF(DSW.NE.0) CALL COND(X1,X2,Y1,Y2)   
      X1=X1*RAD   
      X2=X2*RAD   
      Y1=Y1*RAD   
      Y2=Y2*RAD   
C   TRANSFORM TO EQUATOR   
      CALL INIEQR(X2,Y2,X1,Y1)   
C   
      CALL TOEQR(X1,Y1,X1T,Y1T)   
      CALL TOEQR(X2,Y2,X2T,Y2T)   
C  READ IN UPPER LEFT AND LOWER RIGHT CORNERS OF AFFECTED RECTANGLE   
C  -- DEGREES, MINUTES IE 20.30=20 DEGREES,30 MINUTES (DSW=1)   
C      (DECIMAL DEGREES 20.50 = 20 1/2 DEGREES (DSW=0) )   
C  OPPOSITE CORNERS OF GRIDDED AREA (IN LATITUDE AND LONGITUDE)   
C  GRIDDED AREA BECOMES RECTANGLE SURROUNDING NEW EQUATOR.   
C  SITES ARE AT UNIFORM INCREMENTS IN LATITUDE AND LONGITUDE   
C  WITHIN THIS GRIDDED AREA IN NEW COORDINATE SYSTEM.   
C  IN ORDER TO LIMIT AFFECTED AREA YOU CAN SPECIFY   
C   BEGINNING AND ENDING ROWS AND COLUMNS AS IROW1 AND 2   
C   AND ICOL1 AND 2 (NEXT INPUT LINE)   
C      PH1=PHI=LATITUDE   
C      FL1=LAMBDA=LONGITUDE   
C   
      READ(15,*) FL1,PH1,FL2,PH2,PHINC   
      WRITE (16,160) FL1,PH1,FL2,PH2   
  160 FORMAT(' CORNERS OF GRIDDED AREA-UPPER LEFT=',F7.2,',',F7.2,   
     +/23X,' LOWER RIGHT=',F7.2,',',F7.2)   
C   
C  CONVERT TO DECIMAL DEGREES (UNLESS DSW=0)   
      IF(DSW.EQ.0) GO TO 170   
      CALL COND(PH1,FL1,PH2,FL2)   
      CALL CONDEC(PHINC)   
  170 CONTINUE   
C   
C     DETERMINE NUMBER OF SUBREGIONS IN MAP AREA AND SET UP SUBSCRIPTING   
C     IROW=NO OF ROWS   
C     ICOL=NO OF COLS   
      WRITE(16,180) PHINC,PHINC   
  180 FORMAT(' LONGITUDE INCREMENT=',F7.4,' (DECIMAL DEGREES)',   
     +/,' LATITUDE INCREMENT =',F7.4,' (DECIMAL DEGREES)')   
      PHINC=PHINC*RAD   
      FLINC=PHINC   
      DPHINC=PHINC*R   
      FL1=FL1*RAD   
      PH1=PH1*RAD   
      FL2=FL2*RAD   
      PH2=PH2*RAD   
C    TRANSFORM TO EQUATOR AND X-Y RECTANGULAR COORDINATE SYSTEM   
C    CONVERT TO KILOMETERS   
      CALL TOEQR(FL1,PH1,FLAM1,PHI1)   
      CALL TO EQR(FL2,PH2,FLAM2,PHI2)   
      IF(PHI1.GT.0) GO TO 210   
      IF(PHI2.GT.0) GO TO 220   
C     APPARENT ERROR IN INPUTS OR XFORMATAION   
  190 WRITE(16,200)   
  200 FORMAT(' PROBABLE INPUT ERROR--FELT REGION UPPER LEFT,',  
     +' LOWER RIGHT'/' MUST BE ON OPPOSITE SIDES OF NEW EQUATOR')   
      STOP 6666  
  210  IF(PHI2.LE.0) GO TO 230   
      GO TO 190   
  220 PHS=PHI1   
      PHI1=PHI2   
      PHI2=PHS   
      FLS=FLAM1   
      FLAM1=FLAM2   
      FLAM2=FLS   
C     HAVE PROPER ORIENTATION--CONTINUE   
  230 PH1=PHI1   
      IF(FLAM1.LT.0) GO TO 240   
      FL1=FLAM1   
C    FIND TOTAL NUMBER OF COLS   
      GO TO 260   
  240 WRITE(16,250)FLAM1,FLAM2   
  250 FORMAT(' APPARENT ERROR IN XFORMING LAT AND LONG LIMITS',   
     + 'TO EQR--',/,'  FLAM1=',F9.3,'  FL2=',F9.3)   
      STOP 4444  
  260 CONTINUE   
C   ADJUST TO INCLUDE AREA BEYOND EDGES FOR LATER SMOOTHING   
C     DETERMINE NBORD=NUMBER OF ADDITIONAL ROWS AND COLUMNS AT    
C      WHICH GROUND MOTIONS MUST BE CALCULATED TO ACCOUNT FOR    
C      EARTHQUAKE LOCATION VARIABILITY.   
      NBORD=2.*SIGMAX/DPHINC+.01   
      IF(SIGMAX.EQ.0.) GO TO 280   
      IF(NBORD.GE.2) GO TO 280   
      WRITE (16,270) DPHINC,SIGMAX,NBORD   
  270 FORMAT(' INCREMENTS BETWEEN SITES =',E12.5,' TOO LARGE FOR',   
     + 'SIGMAX=',E12.5,' NBORD=',I5)   
      STOP 3333  
  280 PH1=PH1+NBORD*PHINC   
      IF (FLAM2.GT.FL1) FLINC=-FLINC   
      FL1=FL1+NBORD*FLINC   
      IROW=(PH1-PHI2)/PHINC+1.01+NBORD   
      ICOL=(FL1-FLAM2)/FLINC+1.01+NBORD   
      WRITE(16,290)IROW,ICOL,NBORD   
  290 FORMAT(' GRIDDED REGION CONTAINS',I4,' ROWS, ',I4,' COLS',   
     +' INCLUDING BORDER ',I4,' ROWS AND COLS')   
      READ(15,*)IROW1,IROW2,ICOL1,ICOL2   
C   
C    LIMITS ROWS AND COLUMNS OF FELT POINTS FOR WHICH CALCULATION IS   
C    TO BE MADE.   
C   
      WRITE(16,300)IROW1,IROW2,ICOL1,ICOL2   
  300 FORMAT(' FOR THIS RUN BEGIN AT ROW ',I3,' END ROW ',I3,   
     + ', BEGIN COL ',I3,' END COL ',I3)   
C   FOR EARTHQUAKE LOCATION VARIABILITY, COMPUTE AT MORE SITES   
C   CALCULATE AT ADDITIONAL ROWS AND COLS   
      IROW2=IROW2+2*NBORD   
      ICOL2=ICOL2+2*NBORD   
      ICOLS=ICOL2-ICOL1+1   
      IROWS=IROW2-IROW1+1   
      IF(IROW1.EQ.0) IROWS=0   
      IF(ICOL1.EQ.0) ICOLS=0   
      IF(IROW1.LE.IROW2) GO TO 320   
      WRITE(16,310) IROW1   
  310 FORMAT(' IROW1 =',I4,'  TOO LARGE--ERROR STOP')   
      STOP 8888  
  320 IF(ICOL1.LE.ICOL2) GO TO 340   
      WRITE(16,330) ICOL1   
  330 FORMAT(' ICOL1 =',I4,'   TOO LARGE--ERROR STOP')   
      STOP 9999  
  340 IF(ICOLS*IROWS.LE.MAXAR) GO TO 370   
  350 WRITE(16,360)IROWS,ICOLS,INDVPT,MAXDIM   
  360 FORMAT(' IROWS=',I4,' ICOLS=',I4,' PTS ON LINE=',I4,   
     +' EXCEEDS MAXDIM OF ',I4)   
      STOP 9999  
  370 CONTINUE   
C   READ IN NUMBER OF LINE SEGMENTS CONTAINING SITES AT WHICH   
C   CALCULATION IS TO BE DONE  (IN ADDITION TO OR INSTEAD OF   
C   COMPUTING FOR SITES ON A FIXED GRID)   
C   ZERO IF NO LINE SEGMENTS   
      UPLY=PH1*R   
      UPLX=FL1*R   
      BOTY=PHI2*R   
      BOTX=FLAM2*R   
      WRITE(16,380) UPLX,BOTX,UPLY,BOTY   
  380 FORMAT(' NEW COORDINATES (KM) GRIDDED AREA',   
     +/,'       UPPER LEFT=',2F9.2,'; LOWER RIGHT=',2F9.2)   
      READ(15,*)INDV   
      WRITE(16,390) INDV   
  390 FORMAT(' SITES ARE ALSO LOCATED ON ',I3,' LINE(S)')   
      IF (INDV.EQ.0) GO TO 460   
C     CALCULATE ACCELERATIONS AT NVS SITES ON EACH OF INDV LINES   
C     READ IN END POINT PAIRS (LONG,LAT) XE1,YE1,XE2,YE2   
C     FOR EACH OF INDV LINES   
C     NVS SITES ARE EVENLY SPACED ON LINE*   
C     NVS=2 GIVES ACCELERATIONS AT END POINTS OF LINE;   
C     NVS=3 ACCELERATION AT 2 END POINTS PLUS CENTER OF LINE,ETC.   
      READ(15,*) NVS   
      WRITE(16,400) NVS   
  400 FORMAT(I4,' SITES PER LINE')   
      INDVPT=0   
      DO 450 I=1,INDV   
      READ(15,*) XE1,YE1,XE2,YE2   
      WRITE(16,410) I,XE1,YE1,XE2,YE2   
  410 FORMAT(' LINE ',I2,' END POINTS AT ',F7.3,',',F7.3,' AND ',F7.3,   
     +',',F7.3)   
      IF(DSW.NE.0) CALL COND(XE1,XE2,YE1,YE2)   
      XE1=XE1*RAD   
      XE2=XE2*RAD   
      YE1=YE1*RAD   
      YE2=YE2*RAD   
      CALL TOEQR(XE1,YE1,XO1,YO1)   
      CALL TOEQR(XE2,YE2,XO2,YO2)   
      FR=0.   
      IF (NVS.GT.1) FRINC=1./(NVS-1)   
      DO 440 IQ=1,NVS   
      INDVPT=INDVPT+1   
      IF(INDVPT.LE.500) GO TO 430   
      WRITE(16,420)   
  420 FORMAT(' MORE THAN 500 SINGLE POINTS REQUESTED AS SITES',   
     + 1X,'DO 500')   
      GO TO 460   
  430 XL1=XO1+FR*(XO2-XO1)   
      YP1=YO1+FR*(YO2-YO1)   
      COSY(1)=COS(YP1)   
      SINY(1)=SIN(YP1)   
      SINX(1)=SIN(XL1)   
      COSX(1)=COS(XL1)   
      CALL BACKW(1,1,XPT1(INDVPT),YPT1(INDVPT))   
      XPT2(INDVPT)=XL1*R   
      YPT2(INDVPT)=YP1*R   
      FR=FR+FRINC   
  440 CONTINUE   
  450 CONTINUE   
  460 IF(ICOLS*IROWS+INDVPT.GT.MAXAR) GO TO 350   
      NRC=ICOLS*IROWS   
C   
C     JENT=NUMBER OF MAGNITUDE ENTRIES IN TABLE OF ACCELERATION AS A   
C        FUNCTION OF MAGNITUDE AND DISTANCE   
C     MDIS=NUMBER OF DISTANCE ENTRIES   
      READ(15,*) JENT,MDIS   
      IF (JENT.LE.10) GO TO 480   
      WRITE (16,470) JENT   
  470 FORMAT(' JENT=',I3,' TOO LARGE--MAX 10 ALLOWED')   
      STOP 1111  
  480 IF (MDIS.LE.20) GO TO 500   
      WRITE(16,490) MDIS   
  490 FORMAT(' MDIS=',I4,'  TOO LARGE--MAX 20 DISTANCES ALLOWED')   
      STOP 0000  
  500 CONTINUE   
C     READ IDENTIFIER AND MAGNITUDES FOR WHICH ACCELERATION VERSUS   
C     DISTANCE TABLE FOLLOWS.  MAGNITUDES MUST BE IN DECREASING ORDER   
C   
      READ(15,*)NAM,(TM(I),I=1,JENT)   
C    PRINT MAGNITUDE HEADINGS FOR ATTENUATION FUNCTION.   
      WRITE (16,510) NAM   
  510 FORMAT(' ATTENUATION FUNCTION ',A10/30X,'MAGNITUDE')   
      WRITE(16,520) (TM(I),I=1,JENT)   
  520 FORMAT('   DIST(KM) ',F7.2,10F10.2)   
C  READ IN TABLE OF ACCELERATION VS DISTANCE VALUES FOR SET   
C  OF MAGNITUDES (DISTANCE INCREASING IN TABLE)   
      DO 580 M=1,MDIS   
      READ(15,*) RTAB(M),(ATAB(M,J),J=1,JENT)   
      IF(ATAB(1,1).LT.10) GO TO 540   
      WRITE (16,530) RTAB(M),(ATAB(M,J),J=1,JENT)   
  530 FORMAT(1H ,F10.2,10F10.2)   
      GO TO 560   
  540 WRITE(16,550) RTAB(M),(ATAB(M,J),J=1,JENT)   
  550 FORMAT(1H ,F10.2,8F10.5)   
C  TAKE LOGS OF TABULAR VALUES SINCE INTERP. IS IN LOG ACC. ETC.   
  560 DO 570 J=1,JENT   
  570 ATAB(M,J)=ALOG(ATAB(M,J))   
  580 CONTINUE   
C   
C      DEFINE LIMITS FOR ACCELERATION BOXES:   ACCELERATIONS IN THE   
C      RANGE AC(J-1) < AC < AC(J) WILL BE COLLECTED THE JTH BOX.   
C      MAX=NUMBER OF BOXES;  ACCELERATION VALUES TOO LARGE FOR   
C      ANY OF THE BOX LEVELS CORRESPOND TO MAXP=MAX+1   
C      AS HERE CONSTITUTED BOXES HAVE LIMITS RANGING FROM   
C     .02 TO 1.0   
C     FOR MOTIONS EXCEEDING 1(G)., PROVIDE   
C     APPROPRIATE DISTANCE VS GROUND TABLE AND SELECT 'SCALE'   
C     FOR MULTIPLYING BOXES TO GET CONSISTENT RANGE   
C     OR REWRITE AND RECOMPILE SUBROUTINE BOX   
  600 CALL BOX(SCALE,SD)   
C   
C     BASIC STEP SIZE FOR DISTANCES IN SOURCE AREAS   
      DO 610 I=1,MAXSP   
  610 ACLOG(I)=ALOG(AC(I))   
C     NUMBER OF DIGITS AFTER DECIMAL FOR PRINT OF   
C     ACCELERATIONS (SUBROUTINE OUT) DETERMINED BY SCALE   
C   
C     IDENTIFY ROWS AND COLS FOR FILE02   
  620 IR2=IROW2-2*NBORD   
      ICL2=ICOL2-2*NBORD   
      WRITE(2) IROW1,IR2,ICOL1,ICL2,INDVPT,NTIMS,(JTIM(JV),JV=1,NTIMS),   
     +PROB,SD   
C     CREATE TABLE OF SINES AND COSINES FOR LATER BACK TRANSFORMATION   
C     OF FELT POINTS   
      IF(ICOL1.EQ.0) GO TO 680   
      YP1=(PH1-(IROW1-1.)*PHINC)   
      XL1=(FL1-(ICOL1-1.)*FLINC)   
      IROW2P=IROW2+1   
      ICOL2P=ICOL2+1   
      IF(IROW2P.LE.ISCOM) GO TO 650   
  630 WRITE(16,640) IROW2P,ICOL2P,ISCOM   
  640 FORMAT (I5,' ROWS,',I5,' COLS NEEDED IN SINCOS ARRAYS,',   
     +' DIMENSION=',I4,/' NEED TO INCREASE DIMENSION')   
      STOP 2222  
  650 IF(ICOL2P.GT.ISCOM) GO TO 630   
      DO 660 IRA=IROW1,IROW2P   
      COSY(IRA)=COS(YP1)   
      SINY(IRA)=SIN(YP1)   
  660 YP1=YP1-PHINC   
      DO 670 II=ICOL1,ICOL2P   
      COSX(II)=COS(XL1)   
      SINX(II)=SIN(XL1)   
  670 XL1=XL1-FLINC   
  680 READ(15,700)NUM,YRNOC,IPRINT,TOTL,DUMID,ALS,BLS,SIGLS   
      NUMSAV=NUM   
  690 FORMAT(/'YRNOC= ',F6.0,' IPRINT=',I2,' FOR AREA ',A4)   
  700 FORMAT(I2,F10.0,I2 ,F10.2,A4,2F6.2,F5.2)   
C   
      IF(NUM.NE.99) GO TO 710   
      IF(LINE.EQ.1) GO TO 2950   
C  YRNOC=0 HERE IF ONLY SOURCE AREAS, NO FAULTS INCLUDED   
      IF(YRNOC.EQ.0.) GO TO 2950   
      LINE=1   
  710 WRITE(16,690)YRNOC,IPRINT,DUMID   
  720 IF(LINE.EQ.1) GO TO 830   
      IF(NUM.EQ.98) WRITE (16,705) ALS   
  705 FORMAT(' SMOOTH FOR EARTHQUAKE LOCATION UNCERTAINTY SIGMA=',   
     1 F5.1)   
      NBR=0   
      IST=0   
      IEND=0   
C  READ IDENTIFIERS FOR SOURCE AREA INPUTS   
  730 READ(15,*)JSEG,IFR,ITOT   
C     WRITE(16,740) IFR,ITOT   
  740 FORMAT(' SOURCE ',I2,' OF ',I2)   
C     JSEG=NUMBER OF PAIRS OF QUADRILATERAL END POINTS IN THIS   
C        SINGLE SOURCE   
C     ITOT=NUMBER OF SOURCES IN THIS SOURCE AREA   
C     IFR=IDENTIFIES WHICH SOURCE,  IFR=1,2,....ITOT   
      IF (ITOT.LE.10) GO TO 760   
      WRITE(16,750) ITOT,JSEG,IFR   
  750 FORMAT('  ITOT =',I4,'  TO LARGE--MAX 10  JSEG=',I4,   
     + ' IFR=',I4)   
      STOP 3333  
  760 IST=IEND+1   
      IEND=IST+JSEG-1   
      IF (IEND.LE.50) GO TO 780   
      WRITE(16,770)   
  770 FORMAT('  TOO MANY QUADRILATERALS IN SOURCE--MAX 50')   
      STOP 4444  
C  READ IN BOUNDARIES FOR QUADRILATERALS FOR ALL SUBAREAS   
C  IN THIS SOURCE   
C      READ LIMITS OF SEISMIC AREA X(I)=LAMBDA(I),   Y(I)=PHI(I)   
C      UPPER LEFT(X,Y) THEN  UPPER RIGHT(X,Y) --1ST QUADRILATERAL   
C      2ND LINE   LOWER LEFT,LOWER RIGHT 1ST QUADRILATERAL=   
C      2ND CARD   UPPER LEFT,UPPER RIGHT   2ND QUADRILATERAL,  ETC.   
C   
  780 DO 810 II=IST,IEND   
      READ(15,*)  (XSAV(I,II),YSAV(I,II), I=1,2)   
  790 FORMAT(4F6.0)   
  800 FORMAT(1H ,4F10.3)   
      WRITE(16,800)(XSAV(I,II),YSAV(I,II),I=1,2)   
  810 CONTINUE   
      IF(IFR.EQ.ITOT) GO TO 820   
      NBR=NBR+1   
      IBR(NBR)=IEND   
      GO TO 730   
  820 NUM=IEND   
      GO TO 960   
C     FAULT LINE READ   
  830 J=1   
      WRITE(16,840) TOTL   
  840 FORMAT(' DISTANCE BETWEEN DUMMY FAULTS=',F5.1)   
      DSUM=0.   
C    FAULT INPUTS   
  850 READ(15,*) JSEG ,IFR,ITOT   
      WRITE(16,860) IFR,ITOT   
  860 FORMAT(' FAULT ',I2,' OF ',I2)   
C    JSEG=NUMBER OF END POINTS OF CONNECTED SEGMENTS   
C       FOR THE CURRENT FAULT   
C       JSEG=ONE PLUS NUMBER OF SEGMENTS   
C    ITOT=NUMBER OF DISTINCT FAULTS IN THIS ZONE   
C    IFR IDENTIFIES CURRENT FAULT, IFR=1,2,...ITOT   
      IF (JSEG.LE.24) GO TO 890   
  870 WRITE (16,880) JSEG,ITOT   
  880 FORMAT('  JSEG=',I4,' (MAX 24) ITOT=',I4,' (MAX 26)-STOP')   
  890 IF(ITOT.GT.26) GO TO 870   
C    READ IN END POINTS LONG,LAT OF EACH SEGMENT   
      READ(15,*)(XL(I,J),YP(I,J),I=1,JSEG)   
      WRITE(16,900)(XL(I,J),YP(I,J),I=1,JSEG)   
  900 FORMAT(1H ,4(F10.2,F8.2,','))   
      JM(J)=JSEG   
      DO 920 I=1,JSEG   
C    CONVERT TO DECIMAL DEGREES UNLESS DSW=0   
      IF(DSW.EQ.0) GO TO 910   
      CALL CONDEC(YP(I,J))   
      CALL CONDEC(XL(I,J))   
  910 CONTINUE   
C   TRANSFORM TO EQUATOR--RECTANGULAR COORDINATES   
      YIN=YP(I,J)*RAD   
      XIN=XL(I,J)*RAD   
      CALL TO EQR(XIN,YIN,XOUT,YOUT)   
      XL(I,J)=XOUT*R   
      YP(I,J)=YOUT*R   
  920 CONTINUE   
C   COMPUTE LINE PARAMETERS, LENGTHS FOR FAULT SEGMENTS   
      JSEGM=JSEG-1   
      DTOT(J)=0.   
      DO 930 I=1,JSEGM   
      XDELTA=XL(I+1,J)-XL(I,J)   
      YDELTA=YP(I+1,J)-YP(I,J)   
      DISQ(I,J)=XDELTA*XDELTA+YDELTA*YDELTA   
      DIST(I,J)=SQRT(DISQ(I,J))   
      COA(I,J)=(XL(I+1,J)-XL(I,J))/DIST(I,J)   
      SIA(I,J)=(YP(I+1,J)-YP(I,J))/DIST(I,J)   
  930 DTOT(J)=DTOT(J)+DIST(I,J)   
      DSUM=DSUM+DTOT(J)   
      IF(IFR.EQ.ITOT) GO TO 950   
  940 J=J+1   
      GO TO 850   
C     READ IN NUM OF OCCURRENCES FOR EACH MAGNITUDE (12F6.2)   
C     BOTH AREA AND FAULT INPUT   
  950 JTOT=J   
  960 READ (15,1170) (NOC(I),I=1,12)   
      LEV=12   
  970 IF(NOC(LEV).NE.0.0) GO TO 990   
      LEV=LEV-1   
      IF(LEV.GT.0) GO TO 970   
      WRITE(16,980)   
  980 FORMAT(' APPARENT INPUT ERR FOR NO OF OCCURRENCES AT EACH LEVEL')   
      GO TO 2990   
  990 CONTINUE   
      WRITE(16,1000)LEV   
 1000 FORMAT(' NR OF LEVELS OF SEISMICITY = ',I2)   
C   
C  READ IN CORRESPONDING MAG. INTERVAL CENTER POINTS. (LEV OF THEM)   
C   
 1010 FORMAT(' BEFORE NORMALIZING TO RATE/YEAR')   
 1020 FORMAT( ' EARTHQUAKE RATE / YEAR')   
      READ(15,1170)(FM(I),I=1,LEV )   
C  MAGNITUDES MUST BE EVENLY SPACED AND IN INCREASING ORDER.   
C  IF NOT ENTERED IN INCREASING ORDER, PROGRAM REVERSES ORDER   
C  OF MAGNITUDES AND CORRESPONDING EARTHQUAKE OCCURRENCES   
C  AT EACH MAGNITUDE.   
C  DON'T CONFUSE THIS WITH THE ORIGINAL TABLE OF GROUND   
C   MOTIONS AS A FUNCTION OF MAGNITUDE AND DISTANCE.   
C   THE MAGNITUDES IN THAT TABLE MUST BE READ IN DECREASING   
C   (RATHER THAN INCREASING) ORDER.   
      IF(FM(1).LT.FM(2)) GO TO 1040   
      IF(LEV.EQ.1) GO TO 1040   
      LEVH=LEV/2   
      LL=LEV   
      DO 1030 L=1,LEVH   
      SAV=FM(L)   
      FM(L)=FM(LL)   
      FM(LL)=SAV   
      SAV=NOC(L)   
      NOC(L)=NOC(LL)   
      NOC(LL)=SAV   
 1030 LL=LL-1   
 1040 CONTINUE   
      IF(LEV.GT.1) GO TO 1050   
C    WE CANNOT CALCULATE BETA FROM NUMBERS OF EARTHQUAKES   
C    IF ONLY ONE LEVEL--SO GIVE A DEFAULT BETA SO WE   
C    CAN LATER SPREAD OUT   
      BETA=-2.0   
      FM(2)=FM(1)+.6   
      DELM=.6   
      GO TO 1060   
 1050 CONTINUE   
      DLEV=ABS(FM(1)-FM(2))   
      BETA=ALOG( NOC(2)/NOC(1) )/DLEV   
 1060 WRITE(16,1070)DUMID, BETA   
 1070 FORMAT(1X,A4,' BETA=',F8.4)   
      IF(YRNOC. EQ. 1.) GO TO 1090   
      WRITE(16,1010)   
      WRITE(16,1100) (NOC(LL),LL=1,LEV)   
C     THIS IS A NORMALIZATION TO RATE PER YEAR   
      DO 1080 LM=1,LEV   
      NOC(LM)=NOC(LM)/YRNOC   
 1080 CONTINUE   
 1090 WRITE(16,1020)   
      WRITE(16,1100)(NOC(L),L=1,LEV)   
 1100 FORMAT(' OCCURRENCES=',12F10.6)   
      WRITE(16,1110)(FM(L),L=1,LEV)   
 1110 FORMAT('  MAGNITUDES=',12F10.2)   
      SUMMOC=0.   
      DO 1120 LM=1,LEV   
 1120 SUMMOC=SUMMOC+NOC(LM)   
C     EVALUATE AT TWICE AS MANY MAGNITUDES AS INITIALLY READ   
C     IN IF INOS=1   
      IF(INOS.NE.1)  GO TO 1140   
      DLEV=(FM(2)-FM(1))/2.   
      ZAC=EXP(ABS(BETA)*DLEV)   
      NOC(1)=NOC(1)*ZAC/(1.+ZAC)   
      SUMOC2=NOC(1)   
      LEV=2*LEV   
      FM(1)=FM(1)-DLEV/2.   
      DO 1130 LL=2,LEV   
      FM(LL)=FM(LL-1)+DLEV   
      NOC(LL)=NOC(LL-1)/ZAC   
 1130 SUMOC2=SUMOC2+NOC(LL)   
      WRITE(16,1150) SUMMOC,SUMOC2   
      WRITE(16,1100) (NOC(L),L=1,LEV)   
      WRITE(16,1110) (FM(L),L=1,LEV)   
 1140 CONTINUE   
 1150 FORMAT(' TOTAL EQS=',2E12.5)   
 1160 CONTINUE   
 1170 FORMAT(12F6.2)   
C   
      IF (LINE.EQ.0) GO TO 1250   
C    DETERMINE WHICH RUPTURE LENGTH MAGNITUDE RELATIONSHIP TO USE   
      IF(ALS.EQ.0)   GO TO 1240   
      AL=ALS   
      BL=BLS   
      SIGL=SIGLS   
C     COMPUTE BREAK LENGTH   
 1180 WRITE(16,1190) AL,BL,SIGL   
 1190 FORMAT(' FAULT RUPTURE LENGTH PARAMETERS AL=',F7.3,' BL=',F7.3,   
     +'  SIGL=',F6.2)   
      LINSET=1   
      IF (SIGL.GT.0) GO TO 1230   
C     WHICH SINGLE BREAK DEFAULT DO WE WANT   
C     IF BL=0, AL NON ZERO USE OLD ALGERMISSEN-PERKINS DEFAULT VALUES   
C     USE PARAMETER VALUES SUPPLIED FOR ONE BREAK ONLY   
 1200 DO 1210 I=1,LEV   
 1210 RLLS(1,I)=10.**(AL+BL*FM(I))   
 1220 PRLS(1)=1.   
      NRLS=1   
      GO TO 1350   
C    SET UP RUPTURE LENGTHS AND PROBABILITIES AS FCT OF MAGNITUDE   
C    NRLS LENGTHS PER MAGNITUDE   
C    AL, BL, SIGL NON ZERO   
 1230 CALL PBREAK(FM,AL,BL,SIGL,RLLS,PRLS,LEV,NRLS)   
      GO TO 1350   
 1240 IF (NRLS.EQ.1) GO TO 1200   
      IF(LINSET.EQ.1) GO TO 1230   
C     COMPUTE DEFAULT VALUES   
      AL=-1.085   
      BL=.389   
      SIGL=.52   
      LINSET=1   
      GO TO 1180   
C  CONVERT QUAD CORNER POINTS TO DECIMAL DEGREES  (IF DSW =1)   
C   
 1250 DO 1280 II=1,NUM   
      DO 1280 I=1,2   
      IF(DSW.EQ.0) GO TO 1260   
      CALL CONDEC(XSAV(I,II))   
      CALL CONDEC(YSAV(I,II))   
 1260 CONTINUE   
      XIN=XSAV(I,II)*RAD   
      YIN=YSAV(I,II)*RAD   
      CALL TO EQR(XIN,YIN,XOUT,YOUT)   
      XSAV(I,II)=XOUT*R   
      YSAV(I,II)=YOUT*R   
C     WRITE(16,1270) XSAV(I,II),YSAV(I,II),II   
 1270 FORMAT(' XSAV,YSAV=',2F9.3,' II=',I3)   
 1280 CONTINUE   
C   
 1290 NM=NUM-1   
      STOT=0.   
      DO 1330 II=1,NM   
      IF(NBR.EQ.0) GO TO 1310   
      DO 1300 IQ=1,NBR   
      IF(II.EQ.IBR(IQ)) GO TO 1330   
 1300 CONTINUE   
C    SET LINE PARAMETERS FOR SUBSOURCE   
 1310 CALL SETREG(II)   
      DO 1320 I=1,2   
      X(I)=XSAV(I,II)   
      X(I+2)=XSAV(I,II+1)   
      Y(I)=YSAV(I,II)   
 1320 Y(I+2)=YSAV(I,II+1)   
C    FIND AREA OF SUBREGION II   
      S1=ABS(X(1)*(Y(2)-Y(3))+X(2)*(Y(3)-Y(1))+X(3)*(Y(1)-Y(2)))   
      S2=ABS(X(4)*(Y(2)-Y(3))+X(2)*(Y(3)-Y(4))+X(3)*(Y(4)-Y(2)))   
      SAREA(II)= (S1+S2)/2.   
      STOT=STOT+SAREA(II)   
 1330 CONTINUE   
      EUA=NOC(1)   
C   FIND EARTHQUAKE RATE PER UNIT AREA FOR LOWEST MAGNITUDE   
C   RATE WILL BE PRINTED BUT NOT USED IN PROGRAM   
      DELM=(FM(2)-FM(1))/2.   
      FM1=FM(1)-DELM   
      FM2=FM(1)+DELM   
      EUA=EUA/STOT   
      WRITE(16,1340) DUMID,STOT,EUA,FM1,FM2   
 1340 FORMAT(1H ,A4,' AREA=',F9.0,' SQ KM, RATE/SQ KM=',E12.5,   
     + ' FOR MAGS ',F5.2,'-',F5.2)   
 1350 DLEV=FM(1)-FM(2)   
C    CREATE TABLE OF LOG ACCELERATIONS FOR SET OF MAGNITUDES   
C    IN (TM) FOR THE ORIGINAL SET OF MDIS DISTANCES AS A FUNCTION   
C    OF DISTANCE   
C    NEXT THREE LINES TEST WHETHER TABLE HAS ALREADY   
C     BEEN COMPUTED--IF SO SKIP OVER   
      IF(LEV.GT.LEVNO) GO TO 1360   
      IF(FM(1).NE.FLEVST) GO TO 1360   
      IF(DLEV.EQ.DLEVSV) GO TO 1520   
 1360 DO 1370 ILL=2,JENT   
 1370 TMDIF(ILL)=TM(ILL)-TM(ILL-1)   
      DO 1420 LL=1,LEV   
      DO 1380 IL=2,JENT   
      IF(FM(LL).GT.TM(IL)) GO TO 1390   
 1380 CONTINUE   
      IL=JENT   
 1390 ILM=IL-1   
      DO 1400 J=1,MDIS   
 1400 ATA(J,LL)=ATAB(J,ILM)+(FM(LL)-TM(ILM))/TMDIF(IL)   
     + *(ATAB(J,IL)-ATAB(J,ILM))   
      DO 1410 J=2,MDIS   
 1410 ATADIF(J,LL)=ATA(J,LL)-ATA(J-1,LL)   
 1420 CONTINUE  
C     FIND DISTANCE CORRESPONDING TO EACH ACCELERATION IN   
C     TABLE AC (SET UP IN SUBROUTINE BOX) FOR EACH MAGNITUDE   
      DO 1510 L=1,LEV   
      DO 1500 J=1,MAXP   
      DO 1430 I=2,MDIS   
      IF(ACLOG(J).GT.ATA(I,L)) GO TO 1450   
 1430 CONTINUE   
C     BEYOND TABLE   
 1440 DTAB(J,L)=RTAB(MDIS)   
      GO TO 1500   
 1450 IF(ATADIF(I,L).NE.0) GO TO 1490   
C     NO CHANGE IN ACCELERATION AT THIS DISTANCE   
 1460 IF(I.EQ.2) GO TO 1480   
      WRITE(16,1470) I,L,J   
 1470 FORMAT(' APPARENT ERROR INDIST-TABLE I,L,J=',3I4)   
      STOP 5555  
 1480 DTAB(J,L)=0.   
      GO TO 1500   
 1490 DTAB(J,L)=RTAB(I)-(RTAB(I)-RTAB(I-1))*(ATA(I,L)-ACLOG(J))   
     +/ATADIF(I,L)   
      IF(DTAB(J,L).LT.0) DTAB(J,L)=0.   
 1500 CONTINUE   
 1510 CONTINUE   
      DLEVSV=DLEV   
      LEVNO=LEV   
      FLEVST=FM(1)   
 1520 CONTINUE   
C    ADD HALF VALUES OF MAG FOR LATER SPREADING OUT   
      DMAG=FM(2)-FM(1)   
      BMAG=FM(1)-DMAG/2.   
      LEVP=LEV+1   
      DO 1530 I=1,LEVP   
      GM(I)=BMAG   
 1530 BMAG=BMAG+DMAG   
      DO 1570 LL=1,LEVP   
      DO 1540 IL=2,JENT   
      IF(GM(LL).GT.TM(IL)) GO TO 1550   
 1540 CONTINUE   
      IL=JENT   
 1550 DO 1560 J=1,MDIS   
      ATAH(J,LL)=ATAB(J,IL-1)+(GM(LL)-TM(IL-1))/TMDIF(IL)   
     + *(ATAB(J,IL)-ATAB(J,IL-1))   
 1560 CONTINUE   
 1570 CONTINUE   
C    TAKE EXP DIFFERENCES FOR LATER ACCEL SPREAD OUT   
C    THE "EXDIF" VALUES ARE USED IN SUBROUTINE "SPREAD"   
      IF (LEV.EQ.1) BETAD=2.0   
      IF(LEV.NE.1) BETAD=ALOG(NOC(1)/NOC(2))   
      BETA=BETAD/DMAG   
      FMUL=1./(1.-EXP(-BETA*DMAG))   
      FRAK=EXP(-BETA*DMAG/100.)   
      FRM=FRAK   
      EXDIF(1)=0.   
      DO 1580 I=2,101   
      EXDIF(I)=(1.-FRM)*FMUL   
 1580 FRM=FRM*FRAK   
      DTMAX=DTAB(1,1)   
      IF(DLEV.LT.0) DTMAX=DTAB(1,LEV)   
C     FIND ENTRY FOR EACH MAGNITUDE IN DISTANCE-ACCELERATION TABLE   
C     FOR ZERO DISTANCE (HIGHEST ACCELERATION FOR THAT MAGNITUDE)   
      DO 1600 L=1,LEV   
      J=MAXP   
 1590 IF(DTAB(J,L).NE.0.) GO TO 1600   
      J=J-1   
      GO TO 1590   
 1600 MAXA(L)=J   
C   
      IROW1S=IROW1   
      IROW2S=IROW2   
      ICOL1S=ICOL1   
      ICOL2S=ICOL2   
      IDRC=0   
      DO 2770 ISPT=1,2   
      IF(ISPT.EQ.1) GO TO 1610   
C    CASE OF CALCULATION DONE FOR SINGLE POINTS ON LINE   
      IF(INDVPT.EQ.0) GO TO 2770   
      IROW1S=1   
      IROW2S=1   
      ICOL1S=1   
      ICOL2S=INDVPT   
      GO TO 1620   
 1610 IF(IROW1.EQ.0) GO TO 2770   
 1620 DO 2760 IRA=IROW1S,IROW2S   
C   
      YMID=(PH1-(IRA-1.)*PHINC)*R   
      DO 2750 II=ICOL1S,ICOL2S   
C   
      IDRC=IDRC+1   
      IF(ISPT.EQ.2) GO TO 1630   
      FII=II   
      XMID=(FL1-(FII-1.)*FLINC)*R   
      GO TO 1640   
 1630 XMID=XPT2(II)   
      YMID=YPT2(II)   
 1640 IF(ISW.EQ.0) GO TO 1660   
C   
C    AFTER FIRST TIME THRU, READ ACCELERATIONS CALCULATED   
C    FOR PREVIOUS SOURCES AT THIS SITE (SAVED IN 2 DIMENSIONAL   
C    ARRAY RAWBIN) INTO REG (1 DIMENSIONAL) ARRAY.   
C   
      DO 1650 IQRP=1,MAXDIM   
 1650 REG(IQRP)=RAWBIN(IQRP,IDRC)   
      GO TO 1680   
C   
C   FIRST TIME THRU CLEAR REG ARRAY IF NOT CONTINUATION RUN   
C   
 1660 DO 1670 LL=1,MAXP   
 1670 REG(LL)=0.   
      REGG(IDRC)=9999.999   
C    SET REGG TO MIN DIST FROM FAULT   
C   
C    FOR FIXED  AFFECTED AREA IN ROW IRA, COL II   
C   
C      SOURCE AREA COMPUTATION   
 1680 IF(LINE.EQ.1) GO TO 2120   
      DO 2110 K=1,NM   
      IF(NBR.EQ.0) GO TO 1700   
      DO 1690 IQ=1,NBR   
      IF(K.EQ.IBR(IQ)) GO TO 2110   
 1690 CONTINUE   
 1700 APPROX=0.   
      DO 1710 I=1,2   
      XLL(I)=XSAV(I,K)   
      XLL(I+2)=XSAV(I,K+1)   
      YL(I)=YSAV(I,K)   
      YL(I+2)=YSAV(I,K+1)   
 1710 CONTINUE   
      XR(3)=XLL(1)   
      YR(3)=YL(1)   
      XR(1)=XLL(2)   
      YR(1)=YL(2)   
      XR(2)=XLL(4)   
      YR(2)=YL(4)   
      XR(4)=XLL(3)   
      YR(4)=YL(3)   
      AREAD=SAREA(K)/STOT   
C     DETERMINE WHETHER SITE IS INSIDE OR OUTSIDE K TH QUADRILATERAL   
C     SUBREGION.  FIND DISTANCE RC TO CLOSEST ENDPOINT   
C     AND RF TO FARTHEST END POINT.  SET UP TABLE OF DISTANCE VERSUS   
C     ARC LENGTH FOR DISTANCES IN THE RANGE RC TO RF USING   
C     SUBROUTINES OUTSID OR INSIDE.   
C      ITST=NO OF RADII AT FIXED INCREMENTS BETWEEN RC AND RF   
C           AT WHICH ARC LENGTHS ARE TO BE EVALUATED IN TABLE   
C      ITST=7   SET IN SUBROUTINE RRISK--RECOMPILE TO CHANGE   
      CALL RRISK(XMID,YMID,IN,K,DIS,RC,RF,ITST)   
      IF(IN.EQ.1) GO TO 1740   
      IF(RC.LT.DTMAX) GO TO 1730   
      DO 1720 LL=1,LEV   
 1720 REG(1)=REG(1)+AREAD*NOC(LL)   
      GO TO 2110   
 1730 RCS=RC   
      DISL(1)=RC   
      ANGL(1)=0.   
      ITST=ITST+1   
      IBEG=2   
      GO TO 1750   
 1740 DISL(1)=0.   
      ANGL(1)=0   
      DISL(2)=RC   
      ANGL(2)=PI2*RC   
      IBEG=3   
      IF(RC.GT.0) GO TO 1745  
      IBEG=2  
      ITST=ITST-1  
 1745 RCS=0.   
      ITST=ITST+2   
C   COMPUTE DISTANCE VERSUS ARC LENGTH TABLE FOR EVEN INCREMENTS   
C   IN DISTANCE   
 1750 DO 1810 III=IBEG,ITST   
      IF(IN.EQ.0.) GO TO 1760   
      CALL INSIDE(XMID,YMID,K,DIS,ANGLE)   
      GO TO 1780   
 1760 CONTINUE  
      CALL OUTSID(XMID,YMID,K,DIS,ANGLE)   
 1770 FORMAT('ERR OUTSIDE FOR IRA=',I4,' II=',I4)   
 1780 CONTINUE   
      DISL(III)=DIS   
      ANGL(III)=ANGLE*DIS   
 1810 DIS=DIS+STSIZE   
      ITST=ITST+1   
      DISL(ITST)=RF   
      ANGL(ITST)=0.   
C   COMPUTE DISTANCE VERSUS ARC LENGTH TABLE FOR DISTANCES   
C   TO SELECTED VERTICES AND PERPENDICULARS TO EDGES   
      RCSQ=RC*RC   
      RFSQ=RF*RF   
      DO 1940 I=1,4   
      IRE=0   
      IF(IN.EQ.0) IRE=2   
      IF(SLLQ(I).LE.RCSQ+1.) GO TO 1930   
      IF(SLLQ(I).GE.RFSQ-1.) GO TO 1930   
      DIS=SQRT(SLLQ(I))-.001   
      IF(DIS.LE.RC) GOTO 1930   
C    ADD ANGLE, DISTANCE CORRESPONDING TO VERTEX   
      IF (IN.EQ.0) GO TO 1830   
      CALL INSIDE(XMID,YMID,K,DIS,ANGLE)   
      GO TO 1860   
 1820 IF(MINA(I).NE.3) GO TO 1940   
C   CLOSEST SIDE NEXT   
      DIS=ABS(PERPA(I))   
      IF(DIS.LE.RC+.5) GO TO 1940   
      IF(DIS.GE.RF-.5) GO TO 1940   
      DIS=DIS-.001   
      CALL INSIDE(XMID,YMID,K,DIS,ANGLE)   
      IRE=1   
      GO TO 1860   
 1830 CONTINUE  
      CALL OUTSID(XMID,YMID,K,DIS,ANGLE)   
      GO TO 1860   
 1840 IF(MINA(I).NE.3) GO TO 1940   
      DIS=ABS(PERPA(I))   
      IRE=1   
      DO 1850 IQL=1,4   
      IF(ABS(SLLQ(IQL)-PERPAQ(I)).LE. 2.) GO TO 1940   
 1850 CONTINUE   
      IF(DIS.LE.RC+1.) GO TO 1940   
      IF(DIS.GE.RF-1.) GO TO 1940   
      DIS=DIS-.001   
      CALL OUTSID(XMID,YMID,K,DIS,ANGLE)   
 1860 CONTINUE   
      DO 1890 LL=1,ITST   
      IF(DIS-DISL(LL)) 1900,1920,1890   
 1890 CONTINUE   
C   INSERT NEW DISTANCE, ANGLE   
 1900 JK=ITST   
      DO 1910 MM=LL,ITST   
      ANGL(JK+1)=ANGL(JK)   
      DISL(JK+1)=DISL(JK)   
 1910 JK=JK-1   
      DISL(LL)=DIS   
      ANGL(LL)=ANGLE*DIS   
      ITST=ITST+1   
 1920 IF(IRE.EQ.0) GO TO 1820   
      IF(IRE.EQ.2) GO TO 1840   
      GO TO1940   
 1930 IF(IN)1840,1840,1820   
 1940 CONTINUE   
      ITST=ITST+1   
      DISL(ITST)=RF   
      ANGL(ITST)=0.   
C   FOR EACH MAGNITUDE, SOURCE, DETERMINE FRACTIONAL SOURCE AREA GIVING   
C   ACCELERATION A:  AC(I-1) < A < AC(I)  FOR EACH ENTRY IN ACCELERATION   
C   TABLE AC.  EQUIVALENT TO FINDING FRACTIONAL SOURCE AREA AT DISTANCE   
C   FROM SITE BETWEEN SUCCESSIVE ENTRIES IN ACCELERATION-DISTANCE   
C   TABLE:  DTAB(I,L) < D < DTAB(I-1,L) FOR MAGNITUDE L.   
C   INTERPOLATES FOR DISTANCE IS DISL VS ANGL TABLE   
C   AREA=INTEGRAL(ANGLE*DIST*DELTA(DIST))  FROM DTAB(I-1,L) TO DTAB(I,L)   
      DO 2090 LL=1,LEV   
      STNOC=NOC(LL)/STOT   
      ISWD=0   
      MAXM=MAXA(LL)   
      IF(MAXM.LE.0.) GO TO 1960   
      APPROX=0.   
      IF(IN.EQ.0) GO TO 1950   
      JLO=MAXM   
      GO TO 1980   
 1950 IF(RCS.LT.DTAB(1,LL)) GO TO 1970   
 1960 REG(1)=REG(1)+AREAD*NOC(LL)   
      GO TO 2080   
 1970 JLO=INDPT(DTAB(1,LL),RCS,MAXM)   
 1980 J=JLO   
      IQS=2   
      DO 2060 JK=1,JLO   
      IF(JK.GT.1) GO TO 1990   
      DBOT=RCS   
      DDIS=DTAB(J,LL)   
      IF(DTAB(J,LL).LT.RF) GOTO 2010   
      REG(J+1)=REG(J+1)+SAREA(K)*STNOC   
      GO TO 2080   
 1990 IF(DTAB(J,LL).LT.RF) GO TO 2000   
      DBOT=DTAB(J+1,LL)   
      DDIS=RF   
      ISWD=1   
      GO TO 2010   
 2000 DDIS=DTAB(J,LL)   
      DBOT=DTAB(J+1,LL)   
 2010 ANAREA=0.   
      DO 2020 IQ=IQS,ITST   
      IF(DBOT.LE.DISL(IQ)) GO TO 2030   
 2020 CONTINUE   
      IQ=ITST   
C    DISTANCE EXCEEDS LAST VALUE-ERROR SINCE TABLE SET UP TO HANDLE THIS   
 2030 DTOP=DISL(IQ)   
      IF(DISL(IQ).GT.DDIS) DTOP=DDIS   
      DMID=(DTOP+DBOT)/2.   
      DELR=DTOP-DBOT   
      FR=(DMID-DISL(IQ-1))/(DISL(IQ)-DISL(IQ-1))   
      ANG=ANGL(IQ-1)+(ANGL(IQ)-ANGL(IQ-1))*FR   
      ANAREA=ANAREA+ANG*DELR   
      IF(DTOP.EQ.DDIS) GO TO 2050   
      DBOT=DTOP   
      IQ=IQ+1   
      IF(IQ.LE.ITST) GO TO 2030   
      WRITE(16,2040)   
 2040 FORMAT(' ERR IN ARC AREA COMPUTATION')   
      GO TO 2030   
C    INTERPOLATE IN ANGLE , DISTANCE TABLE   
 2050 APPROX=APPROX+ANAREA   
      REG(J+1)=REG(J+1)+ANAREA*STNOC   
      J=J-1   
      IF(ISWD.EQ.0) GO TO 2060   
      ARERR=(APPROX-SAREA(K))/SAREA(K)   
      ALLERR=ALLERR+1.   
      IF (ABS(ARERR).LT. .05) GO TO 2090   
      TOT5=TOT5+1.   
      IF(ABS(ARERR).LE. .10) GO TO 2090   
      WRITE(16,2100) ARERR,IRA,II,RC,RF,K,LL,IN,DUMID   
      GO TO 2090   
 2060 IQS=IQ   
C     NEED TO ADD REMAINING AREA IF ANY TO LOWEST ACCELERATION   
      DIF=SAREA(K)-APPROX   
      IF(DIF.LT.0) GO TO 2080   
 2070 REG(1)=REG(1)+DIF*STNOC   
 2080 APPROX=SAREA(K)   
 2090 CONTINUE   
 2100 FORMAT(' INT ERR=',F6.3,' ROW ',I2,' COL ',I2,' RC=',   
     + F7.2,' RF=',F7.2,' K=',I2,' LL=',I2,' IN=',I1,1X,A4)   
 2110 CONTINUE   
      GO TO 2730   
C     FAULT COMPUTATION   
 2120 DO 2720 J=1,JTOT   
      JSEG=JM(J)   
      JSEGM=JSEG-1   
      CALL CLDIS(XMID,YMID,J)   
      DO 2160 LL=1,LEV   
C     FILL IN RUPTURE LENGTHS--MAKE  CERTAIN THAT RUPTURE LENGTH   
C     DOES NOT EXCEED TOTAL FAULT LENGTH   
      NRL=NRLS   
      DO 2130 IRL=1,NRL   
      RLL(IRL,LL)=RLLS(IRL,LL)   
 2130 PRLRL(IRL,LL)=PRLS(IRL)   
      IF(RLL(1,LL).LT.DTOT(J)) GO TO 2160   
      RLL(1,LL)=DTOT(J)   
      IF(NRL.EQ.1) GO TO 2160   
 2140 IF(RLL(2,LL).LT.DTOT(J)) GO TO 2160   
      PRLRL(1,LL)=PRLRL(1,LL)+PRLRL(2,LL)   
      NRL=NRL-1   
      IF(NRL.EQ.1) GO TO 2160   
      DO 2150 I=2,NRL   
      PRLRL(I,LL)=PRLRL(I+1,LL)   
 2150 RLL(I,LL)=RLL(I+1,LL)   
      GO TO 2140   
 2160 NRLSV(LL)=NRL   
      PT1=SQRT(SHDIS)   
      IF(PT1.LT.REGG(IDRC)) REGG(IDRC)=PT1   
      IF (ISID.EQ.0) GO TO 2490   
C    DISTANCE IS MONOTONICALLY INCREASING FOR ALL SEGMENTS   
C    (THE DECREASING CASE HAS BEEN CONVERTED TO INCREASING)   
C    OR SINGLE SHORTEST DISTANCE IS INTERIOR TO FAULT   
      DO 2480 LL=1,LEV   
      NRL=NRLSV(LL)   
      FRCON=DTOT(J)/DSUM*NOC(LL)   
      MAXM=MAXA(LL)   
      JLO=INDPT(DTAB(1,LL),PT1,MAXM)   
      IF (JLO.GT.0) GO TO 2170   
C   DISTANCE BEYOND TABLE--LUMP ACCELERATION IN FIRST BOX   
      REG(1)=REG(1)+FRCON   
      GO TO 2480   
 2170 CONTINUE   
      IF (ISID.EQ.1) GO TO 2190   
 2180 IBEG=1   
      IFIN=JSEGM   
      IXT=1   
      DNEAR=DTOT(J)   
      INEAR=JSEGM   
      GO TO 2310   
 2190 IBEG=1   
      IFIN=INEAR   
      IXT=2   
C   DNEAR=DISTANCE ALONG FAULT FROM ONE END TO POINT ON FAULT   
C   CLOSEST TO THE SITE   
C   DNEAR=TOTAL LENGTH OF SEGMENTS 1,2,...INEAR   
C   INEAR DEFINED SUB CLDIS--IN COMMON/EXTRA/   
      DNEAR=0.   
      DO 2200 IQ=1,INEAR   
 2200 DNEAR=DNEAR+DISTL(IQ)   
      DFAR=DTOT(J)-DNEAR   
      TOTAC=0.   
      DO 2220 IRL=1,NRL   
      SMD=RLL(IRL,LL)   
      IF(SMD.LT.DTOT(J)) GO TO 2210   
C     BREAK IS ENTIRE SEGMENT   
      TOTAC=TOTAC+FRCON*PRLRL(IRL,LL)   
      SUMR=TOTAC   
      GO TO 2220   
 2210 SMD2=SMD/2.   
C    FIND FRACTION OF FAULT AT CLOSEST DISTANCE TO SITE   
C    FOR INTERIOR SITE   
      ARCN=SMD2   
      ARCF=SMD2   
      IF(DNEAR.LT.SMD) ARCN=DNEAR-SMD2   
      IF(DFAR.LT.SMD) ARCF=DFAR-SMD2   
      ARCT=ARCN+ARCF   
      IF(ARCT.LT. .0001) GO TO 2220   
      TOTAC=TOTAC+FRCON/(DTOT(J)-SMD)*ARCT*PRLRL(IRL,LL)   
 2220 CONTINUE   
      SUMR=TOTAC   
      TOTACS=TOTACS+TOTAC   
      JLOP=JLO+1   
      IF(TOTL.GT.0) GO TO 2230   
C     SPREAD DUMMY FAULTS OVER "TOTL" KM DISTANCE IF "TOTL" > 0   
C      IF "TOTL" = 0, SPREAD OVER MAGNITUDE INSTEAD   
      CALL SPREAD(REG,JLOP,LL,TOTAC,PT1)   
      GO TO 2310   
 2230 WIDTH=TOTL/2.   
      SUMR=SUMR/TOTL   
      ADD=0   
      IF(ABS(PT1).GT.WIDTH) GO TO 2280   
      QTOT=WIDTH+ABS(PT1)   
      DSVS=0.   
      JLO2=MAXM   
      DO 2270 IQK=1,2   
      JRP=JLO2   
      DO 2250 JK=1,JLO2   
      DL3 =DTAB(JRP,LL)   
      IF(DL3.GT.QTOT) GO TO 2260   
      CARY=DL3-DSVS   
      REG(JRP+1)=REG(JRP+1)+SUMR*CARY   
      ADD=ADD+SUMR*CARY   
      JRP=JRP-1   
 2240 FORMAT(' ADD=',E12.5)   
 2250 DSVS=DL3   
      JRP=0   
 2260 CARY=QTOT-DSVS   
      ADD=ADD+SUMR*CARY   
      REG(JRP+1)=REG(JRP+1)+SUMR*CARY   
      DSVS=0.   
      QTOT=WIDTH-ABS(PT1)   
 2270 JRP=JLO2   
      GO TO 2310   
 2280  DSTART=ABS(PT1)-WIDTH   
      QTOT=TOTL+DSTART   
      JLO2=INDPT(DTAB(1,LL),DSTART,MAXM)   
      DSVS=DSTART   
      JRP=JLO2   
      DO 2290 JK=1,JLO2   
      DL3=DTAB(JRP,LL)   
      IF(DL3.GT.QTOT) GO TO 2300   
      CARY=DL3-DSVS   
      REG(JRP+1)=REG(JRP+1)+SUMR*CARY   
      ADD=ADD+SUMR*CARY   
      JRP=JRP-1   
 2290 DSVS=DL3   
      JRP=0   
 2300 CARY=QTOT-DSVS   
      REG(JRP+1)=REG(JRP+1)+CARY*SUMR   
C   FIND FRAC OF FAULT IN DISTANCE RANGE DTAB(JR,LL) < D <DTAB(JR-1,LL)   
C   FOR EACH MAGNITUDE LL   
 2310 DO 2470 ITHRU=1,IXT   
      JR=JLO   
      ILO=1   
      III=IBEG   
      CASUM=0.   
      IRL=1   
      DSAV=-DLS(III)   
 2320 FRAC=0.   
      JK=1   
      SMD=RLL(IRL,LL)   
      IF(SMD.LT.DTOT(J)) GO TO 2330   
      IF(IXT.EQ.2)GO TO 2450   
C    ADD IN ENTIRE FAULT LENGTH   
      TOTAC=FRCON*PRLRL(IRL,LL)   
      JLOP=JLO+1   
      CALL SPREAD(REG,JLOP,LL,TOTAC,PT1)   
      GO TO 2450   
 2330 CUML=DNEAR-SMD   
      IF(CUML.LE.0) GO TO 2450   
      DO 2340 IQ=IRL,NRL   
 2340 FRAC=FRAC+PRLRL(IQ,LL)/(DTOT(J)-RLL(IQ,LL))   
      FRAC=FRAC*FRCON   
      DLEN=0.   
      DO 2350 IQ=IBEG,IFIN   
      DISREM(IQ)=DISTL(IQ)   
      DLEN=DLEN+DISREM(IQ)   
      IF (DLEN.GE.CUML) GO TO 2370   
 2350 CONTINUE   
      WRITE(16,2360)DLEN,IBEG,IFIN,CUML   
 2360 FORMAT(' ERROR FOR FAULT LINE DLEN=',E12.5,' IBEG=',I3,   
     +' IFIN=',I3,' CUML=',E12.5)   
      STOP 6666  
 2370 DISREM(IQ)=CUML-DLEN+DISREM(IQ)   
 2380 IFINS=IQ   
 2390 DEND=DISREM(III)-DLS(III)   
C     DSAV=STARTING DISTANCE ALONG SEGMENT III   
 2400 CONTINUE   
      DO 2410 JK=ILO,JLO   
      DL3=SQRT(DTAB(JR,LL)**2-PERSQ(III))   
      IF(DL3.GT.DEND) GO TO 2440   
      CAREA=DL3-DSAV   
      CASUM=CASUM+CAREA   
      REG(JR+1)=REG(JR+1)+CAREA*FRAC   
      JR=JR-1   
 2410 DSAV=DL3   
C   AT TOP OF TABLE--REMAINING DIST BEYOND TABLE   
 2420 DO 2430 IQ=IRL,NRL   
      CUML=DNEAR-RLL(IQ,LL)   
 2430 REG(1)=REG(1)+(CUML-CASUM)*PRLRL(IQ,LL)*FRCON   
     + /(DTOT(J)-RLL(IQ,LL))   
      GO TO 2460   
 2440 CAREA=DEND-DSAV   
      CASUM=CASUM+CAREA   
      REG(JR+1)=REG(JR+1)+CAREA*FRAC   
      DSAV=DEND   
C      AT END OF SEGMENT III   
      IF(III.EQ.IFINS)  GO TO 2450   
      III=III+1   
      DSAV=-DLS(III)   
      ILO=JK   
      GO TO 2390   
 2450 IRL=IRL+1   
      ILO=JK   
      IF(IRL.LE.NRL) GO TO 2320   
      IF(ITHRU.EQ.IXT) GO TO2480   
 2460 IRL=1   
      IBEG=INEAR+1   
      IFIN=JSEGM   
      DNEAR=DTOT(J)-DNEAR   
 2470 CONTINUE   
 2480 CONTINUE   
      GO TO 2720   
C     MORE THAN ONE TURNING POINT   
C     BRUTE FORCE.  FIND CONTRIBUTION FOR SINGLE BREAK   
C     INCREMENT BREAK CENTERS BY DISTANCE DELTAL ALONG FAULT FROM   
C     ONE END TO OTHER.   
 2490 CONTINUE   
      DELTAL=10.   
      IF(PT1.GT.100) DELTAL=20.   
      IF(PT1.LT.15.) DELTAL=5.   
      DO 2710 LL=1,LEV   
      NRL=NRLSV(LL)   
      DO 2710 IRL=1,NRL   
      SMD=RLL(IRL,LL)   
      PRNOC=NOC(LL)*PRLRL(IRL,LL)   
      DJ=DTOT(J)-SMD   
      ND=DJ/DELTAL+1.5   
      IF(ND.GT.1) GO TO 2500   
      ND=2   
      IF(DJ.GT.1.) GO TO 2500   
C     BREAK IS ENTIRE FAULT LENGTH   
      MAXM=MAXA(LL)   
      JLO=INDPT(DTAB(1,LL),PT1,MAXM)   
      ADD=PRNOC*DTOT(J)/DSUM   
      JLOP=JLO+1   
      CALL SPREAD(REG,JLOP,LL,ADD,PT1)   
      GO TO 2710   
 2500 CONTINUE   
      DMVP=PRNOC*DTOT(J)/(DSUM*(ND-1))   
      DEL=DJ/(ND-1)   
      DO 2700 M=1,ND   
      DST=(M-1)*DEL   
      DO 2510 I=1,JSEGM   
      IF(DST.LT.DIST(I,J)) GO TO 2530   
      DST=DST-DIST(I,J)   
 2510 CONTINUE   
      WRITE(16,2520)DST,J   
 2520 FORMAT(' APPARENT ERROR FAULT DIST--DST=',E12.5,'  J=',I4)   
      GO TO 2990   
 2530 DDSAV=1.E8   
      DFIN=DST+SMD   
 2540 DOVER=0.   
      IF(DFIN.LE.DIST(I,J)) GO TO 2550   
      DOVER=DFIN-DIST(I,J)   
      DFIN=DIST(I,J)   
 2550 IF(DLS(I).LT.DST) GO TO 2560   
      IF(DLS(I).GT.DFIN) GO TO 2570   
C      SHORTEST DISTANCE TO SEGMENT AT POINT WITHIN SEGMENT   
      DD=PERSQ(I)   
      GO TO 2580   
C      SHORTEST DIST AT START OF SEGMENT   
 2560 DD=(DLS(I)-DST)**2+PERSQ(I)   
      GO TO 2580   
C      SHORTEST DISTANCE AT END OF SEGMENT   
 2570 DD=(DLS(I)-DFIN)**2+PERSQ(I)   
 2580 CONTINUE   
      IF(DD.LT.DDSAV) DDSAV=DD   
      IF(ABS(DOVER).LT.0.001) GO TO 2600   
      DST=0   
      I=I+1   
      DFIN=DOVER   
      IF(I.LE.JSEGM) GO TO 2540   
 2590 FORMAT(' I TOO LARGE I=',I2)   
      WRITE(16,2590) I   
      STOP 8888  
 2600 DIS=SQRT(DDSAV)   
C  HAVE DISTANCE TO SUBSEGMENT OF ARC OF FAULT   
C   
      IF(M.GT.1) GO TO 2610   
      JEN2=INDPT(DTAB(1,LL),DIS,MAXA(LL))   
      DISAV=DIS   
      GO TO 2700   
 2610 DISDIF=DIS-DISAV   
      IF(DISDIF.EQ.0) GO TO 2620   
      DFAC=DMVP/DISDIF   
C    SPREAD OUT CONTRIBUTIONS INTO ACCEL BOXES   
      IF(DISDIF) 2630,2620,2660   
 2620 JLOP=JEN2+1   
      CALL SPREAD(REG,JLOP,LL,DMVP,DIS)   
      GO TO 2700   
C     DISTANCE DECREASING   
 2630 JEN2=JEN2+1   
 2640 DISTAB=DIS-DTAB(JEN2,LL)   
      IF (DISTAB.LT.0) GO TO 2650   
      REG(JEN2)=REG(JEN2)+(DIS-DISAV)*DFAC   
      ADD=(DIS-DISAV)*DFAC   
      IF(ADD.LT.0) PRINT *,2740   
      JEN2=JEN2-1   
      DISAV=DIS   
      GO TO 2700   
 2650 REG(JEN2)=REG(JEN2)+(DTAB(JEN2,LL)-DISAV)*DFAC   
      ADD=(DTAB(JEN2,LL)-DISAV)*DFAC   
      IF(ADD.LT.0) PRINT*,2750   
      DISAV=DTAB(JEN2,LL)   
      JEN2=JEN2+1   
      GO TO 2640   
 2660 IF(JEN2.EQ.0) GO TO 2680   
 2670 DISTAB=DIS-DTAB(JEN2,LL)   
      IF(DISTAB.GT.0) GOTO 2690   
 2680 REG(JEN2+1)=REG(JEN2+1)+(DIS-DISAV)*DFAC   
      ADD=(DIS-DISAV)*DFAC   
      IF(ADD.LT.0) PRINT *, 2780   
      DISAV=DIS   
      GO TO 2700   
 2690 REG(JEN2+1)=REG(JEN2+1)+(DTAB(JEN2,LL)-DISAV)*DFAC   
      ADD=(DTAB(JEN2,LL)-DISAV)*DFAC   
      IF(ADD.LT.0) PRINT*, 2790   
      DISAV=DTAB(JEN2,LL)   
      JEN2=JEN2-1   
      IF (JEN2.GE.1) GO TO 2670   
      GO TO 2680   
 2700 CONTINUE   
 2710 CONTINUE   
C    ABOVE ENDS LOOP FOR MORE THAN ONE TURNING POINT   
 2720 CONTINUE   
 2730 CONTINUE   
      DO 2740 IQR=1,MAXDIM   
 2740 RAWBIN(IQR,IDRC)=REG(IQR)   
C     SAVE ACCELERATIONS FOR THIS SOURCE & SITE IN RAWBIN ARRAY   
C   
C    ENDS LOOP FOR ONE SITE, ONE AREA OR FAULT   
C    REPEAT FOR ALL SITES FOR THIS SOURCE BEFORE GOING ON TO NEXT   
C    SOURCE   
 2750 CONTINUE   
 2760 CONTINUE   
C    ONE SOURCE COMPLETED FOR ALL SITES   
 2770 CONTINUE   
C----SMOOTH HERE IF SIGMA FOR EARTHQUAKE LOCATIONS HAS CHANGED   
C----FROM PREVIOUS VALUE   
      IF(LINE.EQ.1) GO TO 2850   
C-----NO SMOOTHING FOR FAULTS   
      IF(NUMSAV.NE.98) GO TO 2850   
C   IF SIGMA=0, NO SMOOTHING   
      IF(ALS.EQ.0) GO TO 2850   
       IF(NRC.EQ.0) GO TO 2850   
C-----   
      SIGD=(DPHINC/ALS)**2   
      DO 2780 IM=1,IMAXSQ   
      FAC(IM)=EXP((-IM*SIGD)/2.)   
 2780 CONTINUE   
      EQSUM=0.   
C    COMPUTE ICON BASED ON SIGMA AND DPHINC   
C    PROBABLY ENOUGH TO GO OUT 2 SIGMA ON EITHER SIDE OF POINT   
C    FIND HOW MANY ROWS OR COLUMNS THAT CORRESPONDS TO   
      ICON=2*ALS/DPHINC+1.01   
      IF(ICON.LT.5) ICON=5   
C   IF ICON<5, SET ICON=5   
      IRM=IROW2-NBORD  
      ICM=ICOL2-NBORD  
      ISUB1=IROW1+NBORD  
      ISUB2=ICOL1+NBORD  
      DO 2830 IIA=ISUB2,ICM  
      J1=IIA-ICON  
      J2=IIA+ICON  
      IF(J2.GT.ICOL2) J2=ICOL2  
      IF(J1.LT.ICOL1) J1=ICOL1  
      DO 2830 IRAA=ISUB1,IRM  
      I1=IRAA-ICON  
      I2=IRAA+ICON  
      IF(I1.LT.IROW1) I1=IROW1  
      I2=IRAA+ICON  
      IF(I2.GT.IROW2) I2=IROW2  
      DO 2800 IQ=1,MAXP  
      ADD=0.  
      WTT=0.  
      DO 2790 I=I1,I2  
      DO 2790 J=J1,J2  
      KSQ=(IRAA-I)**2+(IIA-J)**2  
      IF(KSQ.GT.IMAXSQ) GO TO 2790  
C     WE NEED TO CONVERT TO PROPER SUBSCRIPT IN RAWBIN  
C      IN RAWBIN, FIRST ALL COLS FOR ONE ROW  
C      (I-1)*ICOL(S)+J=ROW AND COL WITH SINGLE SUBSCRIPT IN RAWBIN  
      ISUB=(I-IROW1)*ICOLS+J-ICOL1+1  
      ADD=ADD+FAC(KSQ)*RAWBIN(IQ,ISUB)  
      WTT=WTT+FAC(KSQ)  
 2790 CONTINUE  
      REG(IQ)=0  
      IF(WTT.NE.0) REG(IQ)=ADD/WTT  
      EQSUM=EQSUM+REG(IQ)  
 2800 CONTINUE  
 2810 CONTINUE  
      ISUB=(IRAA-IROW1)*ICOLS+IIA-ICOL1+1  
      DO 2820 IQ=1,MAXDIM  
 2820 SMOBIN(IQ,ISUB)=REG(IQ)+SMOBIN(IQ,ISUB)  
 2830 CONTINUE  
C   NOW DELETE ENTRIES FROM RAWBIN ARRAY  
      DO 2840 ISUB=1,NRC  
      DO 2840 IQ=1,MAXDIM  
 2840 RAWBIN(IQ,ISUB)=0.  
 2850 CONTINUE  
      IF(IPRINT.LT.0) GO TO 2940  
C  OUTPUT ALL RESULTS TO THIS POINT  
      DO 2930 ISPT=1,2  
      IF (ISPT.EQ.1) GO TO 2860  
      IF(INDVPT.EQ.0) GO TO 2930  
      IROW1S=1  
      IROW2S=1  
      ICOL1S=1  
      ICOL2S=INDVPT  
      GO TO 2870  
 2860 IF(IROW1.EQ.0) GO TO 2930  
      IROW1S=IROW1+NBORD  
      IROW2S=IROW2-NBORD  
      ICOL1S=ICOL1+NBORD  
      ICOL2S=ICOL2-NBORD  
 2870 DO 2920 IRA=IROW1S,IROW2S  
      DO 2920 II=ICOL1S,ICOL2S  
      IF(ISPT.EQ.1) GO TO 2890  
 2880 XOUTS=XPT1(II)  
      YOUTS=YPT1(II)  
      ISUB=IROWS*ICOLS+II  
      GO TO 2900  
C     BACK TRANSFORM POINT FROM EQUATOR TO DEC DEGREES  
 2890 CALL BACKW(II,IRA,XOUTS,YOUTS)  
C     RESULTS CALCULATED AND PRINTED IN SUBROUTINE OUT  
      ISUB=(IRA-IROW1)*ICOLS+II-ICOL1+1  
 2900 DO 2910 IQR=1,MAXP  
 2910 REG(IQR)=RAWBIN(IQR,ISUB)+SMOBIN(IQR,ISUB)  
      RDIS=REGG(ISUB)  
      IF(IPRINT.LE.2) WRITE(16,30)TYTLE  
      CALL OUT(REG,NAF,XOUTS,YOUTS,SD)  
 2920 CONTINUE  
 2930 CONTINUE  
 2940 CONTINUE  
      ISW=1  
      GO TO 680  
C     FINISHED  
 2950 NVALS=ICOLS*IROWS+INDVPT  
C     WRITE TO UNIT 3 FOR POSSIBLE RUN CONTINUATION  
C     MAY DELETE TO SAVE TIME AND SPACE IF NO RUN  
C     CONTINUATIONS ARE DESIRED.  
      DO 2970 I=1,NVALS  
      DO 2960 IQR=1,MAXDIM  
 2960 REG(IQR)=RAWBIN(IQR,I)+SMOBIN(IQR,I)  
      WRITE(3) REG  
 2970 CONTINUE  
C    TRANSFER TO UNIT 3 FOR POSSIBLE CONTINUATION OR RESTART  
 2980  CONTINUE  
 2990 CONTINUE  
C     WRITE(16,2530) TOT5,ALLERR  
 3000 FORMAT(/' SOURCES WITH ERROR IN AREA > .05=',F7.0,  
     + ' OUT OF ',F7.0,' SOURCES ')  
 3010 FORMAT(' NUMBER OF BRUTE FORCE POINTS=',I4)  
      STOP 7777  
      END  
      SUBROUTINE COND(X1,X2,Y1,Y2)  
      CALL CONDEC(X1)  
      CALL CONDEC(X2)  
      CALL CONDEC(Y1)  
      CALL CONDEC(Y2)  
      RETURN  
      END  
      SUBROUTINE CONDEC(PHI)  
      I=PHI  
C     FR=PHI-I  
      PHI=FLOAT(I)+(PHI-FLOAT(I))/.60  
      RETURN  
      END  
C ***************************************************************  
      SUBROUTINE LIN(X1,Y1,X2,Y2,A,B,C,X3,Y3)  
C   COEFFICIENTS A, B, C ARE DETERMINED SO THAT POINTS WHICH ARE IN THE  
C   SAME HALF PLANE AS X3,Y3 WILL BE A POSITIVE DISTANCE FROM THE LINE  
C   JOINING X1,Y1 AND X2,Y2  
C       A X + B Y + C=0  
      IF(X1.EQ.X2) GO TO 10  
      A=(Y1-Y2)/(X1-X2)  
      B=-1  
      C=Y1-A*X1  
      GO TO 20  
   10 A=1.  
      B=0  
      C=-X1  
   20 D=A*X3+B*Y3+C  
      IF(D.GT.0.) RETURN  
      A=-A  
      B=-B  
      C=-C  
      RETURN  
      END  
C ***************************************************************  
      SUBROUTINE LININT(REG,T,SOL)  
C     CALCULATES ACCELERATION "SOL" THAT HAS PROBABILITY  
C     "PROB" OF NOT BEING EXCEEDED DURING "T" YEARS AT  
C     SITE.  
C     EXPECTED YEARLY ACCELERATIONS IN THE RANGE  
C     AC(J-1) < A < AC(J) ARE IN REG(J).  
C     LININT IS CALLED FROM SUBROUTINE OUT.  
      COMMON/TIMS/DUMMY(42),IPRINT  
      COMMON/QUAD/MAXP,AC(105),DUMLOG,ACLOG(105)  
      COMMON/EXT/PROB,EX,EXL  
      DIMENSION REG(106)  
      II=MAXP-1  
      SUM=0.  
   10 IF(II.LE.2) GO TO 20  
      IF(REG(II).GT.0.) GO TO 40  
      II=II-1  
      GO TO 10  
   20 SOL=0.  
      IF(IPRINT.LE.2) WRITE(16,30)  
   30 FORMAT(' SOL NOT OBTAINED FOR TIME=',F7.0)  
      RETURN  
   40 SUM=SUM+REG(II)  
      IF(T*SUM.GT.EX) GO TO 50  
      II=II-1  
      IF(II.GE.2) GO TO 40  
      GO TO 20  
   50 IF(SUM.EQ.REG(II)) GO TO 70  
      Y2=ALOG(T*(SUM-REG(II)))  
      Y1=ALOG(T*SUM)  
      EXLT=EXL  
   60 A=(Y1-Y2)/(AC(II-1)-AC(II))  
      B=Y1-A*AC(II-1)  
      SOL=(EXLT-B)/A  
      RETURN  
   70 Y1=T*SUM  
      Y2=0.  
      EXLT=EX  
      IF(IPRINT.LE.2) WRITE(16,80)  
   80 FORMAT(' LOG INTERPOLATION FAILS--USE LINEAR')  
      GO TO 60  
      END  
C ***************************************************************  
      SUBROUTINE BOX(SCALE,SD)  
C    DETERMINE BOUNDARIES AC(I) FOR ACCELERATION LEVELS  
C    ACCELERATIONS IN THE RANGE AC(I-1) < A <AC(I) WILL BE  
C    ACCUMULATED IN REG(I)  
C    SCALE MULTIPLIES THE BASIC LEVELS COMPUTED  
C    SCALE=1 FOR ACCELERATIONS IN THE RANGE .02 TO 1.  
      COMMON /QUAD/MAXQ,AC(105),DUMLOG,ACLOG(105)  
      COMMON/WDS/MAX,MAXP,MAXSP  
      MAXSP=104  
      MAX=54  
      MAXP=55  
      AC(5)=.02*SCALE  
      DIF=AC(5)  
      DO 10 I=6,55  
      AC(I)=AC(I-1)+DIF  
   10 CONTINUE  
C -----------------NOTE IMPORTANT--------------  
C     THE FOLLOWING INSERTED TO ALLOW ACCELERATION BOXES FOR SMALL  
C     VALUES BELOW RANGE OF INTEREST FOR SD COMPUTATION  
C     THIS SHOULD BE CHANGED LATER AS DESIRED  
      J=4  
      EFAC=EXP(-SD/2.)  
      DO 20 I=1,4  
      AC(J)=AC(J+1)*EFAC  
   20 J=J-1  
C   FOR LATER ATTENUATION VARIABILITY, EXPAND ACCELERATION RANGE  
C   USED ONLY IN SUBROUTINE "OUT"  
      Y=ALOG(AC(MAX))  
      W=EXP(Y+4.4*SD)  
      W1=EXP(Y+2.0*SD)  
C    DIMENSION OF AC, ACLOG IS 105; WE CANNOT EXCEED THIS DIMENSION  
      N=MAXSP-MAX  
      N2=N/2  
      I2S=MAX+N2  
      DIF=(W1-AC(MAX))/N2  
      DO 30 I=MAXP,I2S  
      AC(I)=AC(I-1)+DIF  
   30 CONTINUE  
      I2SP=I2S+1  
      DIF=(W-AC(I2S))/N2  
      DO 40 I=I2SP,MAXSP  
      AC(I)=AC(I-1)+DIF  
   40 CONTINUE  
      RETURN  
      END  
C **************************************************************  
      SUBROUTINE INIEQR(X1,Y1,X2,Y2)  
C    READ XLONG, YLAT IN RADIANS FOR 1ST POINT  
C    READ XLONG, YLAT IN RADIANS FOR 2ND POINT  
C    POINTS 1 AND 2 TO BE TRANSFORMED TO EQUATOR  
C    POINT 1 WILL BE TRANSFORMED TO (0,0)  
C    POINT 2 WILL BE TRANSFORMED TO (D,0)  
C   WHERE D=GREAT CIRCLE DISTANCE BETWEEN (X1,Y1) AND (X2,Y2)  
C    OUTPUT IS TRANSFORMATION MATRICES F (FORWARD) FI (BACKWARD)  
C      GENERATED AND STORED IN COMMON  
      COMMON/EQR/ R1(3,3),R2(3,3),R3(3,3),D(3,3),F(3,3),VEC(3)  
      COMMON/INV/FI(3,3),RES(3)  
      CP1=COS(Y1)  
      CP2=COS(Y2)  
      CL1=COS(X1)  
      SP1=SIN(Y1)  
      SP2=SIN(Y2)  
      SL1=SIN(X1)  
C  INITIALIZE MATRICES  
      DO 10 I=1,3  
      DO 10 J=1,3  
      R1(I,J)=0.  
      R2(I,J)=0.  
   10 R3(I,J)=0.  
      R1(1,1)=1.  
      R2(2,2)=1.  
      R3(3,3)=1.  
      R2(1,1)=CP1  
      R2(3,3)=CP1  
      R2(1,3)=SP1  
      R2(3,1)=-SP1  
      R3(1,1)=CL1  
      R3(2,2)=CL1  
      R3(1,2)=SL1  
      R3(2,1)=-SL1  
      S1=CP1*SP2-SP1*CP2*COS(X2-X1)  
      C1=CP2*SIN(X2-X1)  
      DEN=SQRT(C1*C1+S1*S1)  
      SINTH=S1/DEN  
      COSTH=C1/DEN  
      R1(2,2)=COSTH  
      R1(3,3)=COSTH  
      R1(2,3)=SINTH  
      R1(3,2)=-SINTH  
      CALL MATMPY(R1,R2,D)  
      CALL MATMPY(D,R3,F)  
C   TRANSFORMATION MATRIX IN F! INVERSE MATRIX IN FI  
C   COMPUTE INVERSE  
      DO 20 I=1,3  
      DO 20 J=1,3  
      R1(I,J)=0.  
      R2(I,J)=0.  
      R3(I,J)=0.  
   20 CONTINUE  
      R1(3,3)=1.  
      R2(2,2)=1.  
      R3(1,1)=1.  
      R1(1,1)=CL1  
      R1(2,2)=CL1  
      R1(2,1)=SL1  
      R1(1,2)=-SL1  
      R2(1,1)=CP1  
      R2(3,3)=CP1  
      R2(1,3)=-SP1  
      R2(3,1)=SP1  
      R3(2,2)=COSTH  
      R3(3,3)=COSTH  
      R3(3,2)=SINTH  
      R3(2,3)=-SINTH  
      CALL MATMPY(R1,R2,D)  
      CALL MATMPY(D,R3,FI)  
      RETURN  
      END  
C ***************************************************************  
      SUBROUTINE TOEQR(X3,Y3,FLAM6,PHI6)  
C    TRANSFORM POINT AT (X3,Y3)  (LONG,LAT IN RADIANS) TO NEW  
C    EQUATOR USING TRANSFORMATION DEFINED IN SUBROUTINE INEQR  
      COMMON/EQR/  R1(3,3),R2(3,3),R3(3,3),D(3,3),F(3,3),VEC(3)  
      COMMON/INV/FI(3,3),RES(3)  
      CXMID=COS(X3)  
      CYMID=COS(Y3)  
      SXMID=SIN(X3)  
      SYMID=SIN(Y3)  
      VEC(1)=CXMID*CYMID  
      VEC(2)=SXMID*CYMID  
      VEC(3)=SYMID  
      CALL VECMPY(F,VEC,RES)  
      PHI6=ASIN(RES(3))  
      CP6=COS(PHI6)  
      CL6=RES(1)/CP6  
      SL6=RES(2)/CP6  
      IF(CL6.GT.1.) CL6=1.  
      FLAM6=ACOS(CL6)  
      IF(SL6.LT.0.) FLAM6=-FLAM6  
      RETURN  
      END  
C ***************************************************************  
      SUBROUTINE BACKW(IX,IY,FLII,PHII)  
C     FOR PRINTOUT AND IDENTIFICATION: POINT DEFINED BY  
C     ROW IX AND COL IY IN NEW COORDINATE SYSTEM IS TRANSFORMED  
C     TO LOCATION (LONG, LAT. IN DEC DEGREES) IN ORIGINAL     
C     COORDINATE SYSTEM.  
      COMMON/INV/FI(3,3),RES(3)  
      DIMENSION VEC(3)  
C     NEED COS, SINS IN COMMON ARRAY  
      COMMON/SINCOS/SINX(500),COSX(500),SINY(500),COSY(500)  
      DATA RAD/.0174533/  
      SL6=SINX(IX)  
      CL6=COSX(IX)  
      CP6=COSY(IY)  
      SP6=SINY(IY)  
      VEC(1)=CL6*CP6  
      VEC(2)=SL6*CP6  
      VEC(3)=SP6  
      CALL VECMPY(FI,VEC,RES)  
      IF(ABS(RES(3)).LT.1.0) GO TO 30  
      IF(RES(3).GE.1.) GO TO 10  
      PHII=-90.  
      GO TO 20  
   10 PHII=90.  
   20 FLII=0.  
      RETURN  
   30 PHII=ASIN(RES(3))  
      CPI=COS(PHII)  
      PHII=PHII/RAD  
      CLI=RES(1)/CPI  
      SLI=RES(2)/CPI  
      FLII=ACOS(CLI)  
      IF(SLI.LT.0.) FLII=-FLII  
      FLII=FLII/RAD  
      RETURN  
      END  
C ***************************************************************  
      SUBROUTINE MATMPY(A,B,C)  
C    MULTIPLY TWO 3 X 3 MATRICES A X B = C  
      DIMENSION A(3,3),B(3,3),C(3,3)  
      DO 10 I=1,3  
      DO 10 J=1,3  
      C(I,J)=0.  
      DO 10 K=1,3  
   10 C(I,J)=C(I,J)+A(I,K)*B(K,J)  
      RETURN  
      END  
C ***************************************************************  
      SUBROUTINE VECMPY(F,VEC,R)  
C     VECTOR MULTIPLICATION USED BY SUBROUTINES BACKW, TOEQR  
      DIMENSION F(3,3),VEC(3),R(3)  
      DO 10 I=1,3  
      R(I)=0.  
      DO 10 K=1,3  
   10 R(I)=R(I)+F(I,K)*VEC(K)  
      RETURN  
      END  
C ****************************************************************  
      SUBROUTINE CSQDIS(X,Y,XL,YL,XR,YR,ISUB)  
C     FOR A QUADRILATERAL SOURCE AREA, CALCULATES  
C     NEAREST DISTANCE FROM SITE AT (X,Y) TO EACH SIDE  
C     AND DISTANCE TO EACH VERTEX.  
C     CALLED FROM SUBROUTINE RRISK  
      DIMENSION XL(4),YL(4),XR(4),YR(4)  
      COMMON/SLINP/FSA(4,50),FSB(4,50),FSC(4,50),RTA(4,50),DIST(4,50)  
     + ,DISQ(4,50)  
      COMMON /SLINDS/DLS(4),PERP(4),SL1(4),SLSQ(4),MIN(4),PERSQ(4)  
     +,SRSQ(4),DLP(4)  
      DO 10 I=1,4  
   10 PERP(I)=(FSA(I,ISUB)*X+FSB(I,ISUB)*Y+FSC(I,ISUB))/RTA(I,ISUB)  
      DO 20 I=1,4  
      SLSQ(I)=(X-XL(I))**2+(Y-YL(I))**2  
      SRSQ(I)=(X-XR(I))**2+(Y-YR(I))**2  
   20 CONTINUE  
      DO 50 I=1,4  
      PERSQ(I)=PERP(I)*PERP(I)  
      DL1=SLSQ(I)-PERSQ(I)  
      DL2=SRSQ(I)-PERSQ(I)  
      IF(DL1.LT.0.) DL1=0.  
      IF(DL2.LT.0.) DL2=0.  
      IF(DL1+DL2.LE.DISQ(I,ISUB)) GO TO 40  
C      SHORTEST DISTANCE EXTERNAL TO SEGMENT  
      IF(DL1.LT.DL2) GO TO 30  
      MIN(I)=1  
      DLP(I)=SQRT(DL2)  
      DLS(I)=DIST(I,ISUB)+DLP(I)  
      GO TO 50  
   30 MIN(I)=2  
      DLS(I)=-SQRT(DL1)  
      GO TO 50  
   40 MIN(I)=3  
      DLS(I)=SQRT(DL1)  
      DLP(I)=0.  
   50 CONTINUE  
      RETURN  
      END  
C ***************************************************************  
      SUBROUTINE RRISK(XNOT,YNOT,IN,ISUB,R,RC,RF,ITST)  
       COMMON/INOUT/IC,ICS,IFAR,AZIMF,STSIZE,DUM1  
       COMMON/XYAREA/XSAV(2,50),YSAV(2,50),SAREA(50)  
       COMMON/SLINDS/DLS(4),PERP(4),SL1(4),SLSQ(4),MIN(4),PERSQ(4)  
     +,SRSQ(4),DLP(4)  
       COMMON/SLINP/AA(4,50),BB(4,50),CC(4,50),RTA(4,50),DIST(4,50),  
     + DISQ(4,50)  
      COMMON/XLYL/XL(4),YL(4),XR(4),YR(4),XC(4),YC(4)  
C         SUBROUTINE WHICH LOADS TEMPORARY ARRAYS WITH THIS  
C           SUBSOURCE'S CORNERS AND DETERMINES IF THIS SITE IS  
C           INSIDE OR OUTSIDE THE SUBROURCE.  
      DATA PI2/6.2831853/  
C   FIXED NUMBER OF RADII AT WHICH DISTANCE-VS ARC LENGTH  
C   TABLE IS COMPUTED IS SET HERE   ITST=7 ***************  
      ITST=7  
      RC2=10000000.  
      ICS=0  
      CALL CSQDIS(XNOT,YNOT,XL,YL,XR,YR,ISUB)  
      RF2=0.  
      DO 20 II=1,4  
      IF(SLSQ(II).GT.RC2) GO TO 10  
      RC2=SLSQ(II)  
   10 IF(SLSQ(II).LT.RF2) GO TO 20  
      RF2=SLSQ(II)  
      IFAR=II  
   20 CONTINUE  
      DO 30 II=1,4  
      IF(MIN(II).NE.3) GO TO  30  
      IF(PERSQ(II).GT.RC2) GO TO 30  
      RC2=PERSQ(II)  
      ICS=II  
   30 CONTINUE  
      RC=SQRT(RC2)  
      RF=SQRT(RF2)  
      STSIZE=(RF-RC)/ITST  
C        STEP THRU SOURCE AREA.  
      R=RC+(0.5)*STSIZE  
C        DETERMINE IF SITE IS INSIDE SOURCE AREA.  
   40 DO 50 II=1,4  
      D=AA(II,ISUB)*XNOT+BB(II,ISUB)*YNOT+CC(II,ISUB)  
      IF(D.LT.0)GO TO 90  
   50 CONTINUE  
      IN=1  
C          DETERMINE AZIMUTH OF FARTHEST POINT WITH RESPECT TO SITE  
      AZIMF=ACOS((XL(IFAR)-XNOT)/RF)  
      IF (YL(IFAR)-YNOT) 60,70,70  
   60 AZIMF=PI2 - AZIMF  
   70 CONTINUE  
C      RC IS NOW DISTANCE FROM SITE TO CLOSEST SIDE.  
C      RF IS NOW DISTANCE FROM SITE TO FARTHEST CORNER.  
C        PICK STEP SIZE BASED ON FRACTION OF AREA LEFT  
   80 RETURN  
C        IF DO LOOP FINISHED, POINT LIES WITHIN AREA.  
   90 IN=0  
  100 RETURN  
      END  
C **************************************************************  
      SUBROUTINE SETREG(ISUB)  
C    FIND EQUATION OF LINE THRU EACH SIDE OF QUADRILATERAL  
C   FIND LENGTH OF EACH SIDE, ETC.  
      COMMON/OUTS/XOUTS,YOUTS  
      DIMENSION XL(4),YL(4),XR(4),YR(4)  
      COMMON/XYAREA/XSAV(2,50),YSAV(2,50),SAREA(50)  
      COMMON/SLINP/AA(4,50),BB(4,50),CC(4,50),RTA(4,50),DIST(4,50),  
     + DISQ(4,50)  
      DO 10 I=1,2  
      XL(I)=XSAV(I,ISUB)  
      XL(I+2)=XSAV(I,ISUB+1)  
      YL(I)=YSAV(I,ISUB)  
      YL(I+2)=YSAV(I,ISUB+1)  
   10 CONTINUE  
      XR(3)=XL(1)  
      YR(3)=YL(1)  
      XR(1)=XL(2)  
      YR(1)=YL(2)  
      XR(2)=XL(4)  
      YR(2)=YL(4)  
      XR(4)=XL(3)  
      YR(4)=YL(3)  
C        DETERMINE IF ANY SIDES ARE VERTICAL LINES  
      DO 70 II=1,4  
      IF(XL(II).EQ.XR(II)) GO TO 20  
      AA(II,ISUB)=(YL(II)-YR(II))/(XL(II)-XR(II))  
      BB(II,ISUB)=-1.  
      CC(II,ISUB)=YL(II)-AA(II,ISUB)*XL(II)  
      GO TO 30  
   20 AA(II,ISUB)=1.  
      BB(II,ISUB)=0.  
      CC(II,ISUB)=-XL(II)  
   30 IF(II.GT.2) GO TO 40  
      D=AA(II,ISUB)*XL(3)+BB(II,ISUB)*YL(3)+CC(II,ISUB)  
      GO TO 50  
   40 D=AA(II,ISUB)*XL(2)+BB(II,ISUB)*YL(2)+CC(II,ISUB)  
   50 IF (D.GT.0.) GO TO 60  
      AA(II,ISUB)=-AA(II,ISUB)  
      BB(II,ISUB)=-BB(II,ISUB)  
      CC(II,ISUB)=-CC(II,ISUB)  
   60 DISQ(II,ISUB)=(XR(II)-XL(II))**2+(YR(II)-YL(II))**2  
      DIST(II,ISUB)=SQRT(DISQ(II,ISUB))  
   70 RTA(II,ISUB)=SQRT(AA(II,ISUB)*AA(II,ISUB)+BB(II,ISUB)*  
     +BB(II,ISUB))  
      RETURN  
      END  
      FUNCTION INDPT(Y,YVAL,N)  
C      POINTS IN DESCENDING ORDER--NON ZERO VALUES FROM POINTS  
C      1 TO N:  FIND FIRST VALUE IN TABLE EXCEEDING YVAL  
      DIMENSION Y(102)  
      IF(YVAL.LT.Y(1)) GO TO 10  
      INDPT=0  
      RETURN  
   10 IF(YVAL.GT.Y(N)) GO TO 20  
      INDPT=N  
      RETURN  
   20 NUM=N  
      IDIV=2  
   30 NH=NUM/IDIV  
      IF(NH.LE.1) GO TO 50  
      IF(YVAL.LT.Y(NH)) GO TO 40  
      IDIV=2*IDIV  
      GO TO 30  
C    YVAL LIES APPROX BETWEEN NH AND 2*NH OR 2*NH  
   40 IDIV=2*IDIV  
      NH2=NH+NUM/IDIV  
      IF(NH.EQ.NH2) GOTO 80  
      IF(YVAL.GT.Y(NH2)) GO TO 40  
C    YVAL FURTHER DOWN ON TABLE THAN Y(NH2)  
      NH=NH2  
      GO TO 40  
   50 DO 60 I=1,N  
      IF(Y(I).LT.YVAL) GO TO 70  
   60 CONTINUE  
   70 INDPT=I-1  
      RETURN  
   80 CONTINUE  
      DO 90 I=NH,N  
      IF(Y(I).LT.YVAL) GO TO70  
   90 CONTINUE  
      END  
C **************************************************************  
      SUBROUTINE CLDIS(X,Y,JL)  
C     SUBROUTINE TO COMPUTE SHORTEST DISTANCE, ETC TO LINE  
C     CONTAINING FAULT SEGMENT I OF JL TH FAULT (FOR EACH I)  
C     DETERMINES WHETHER CLOSEST POINT TO FAULT IS AT  
C     LOW END (MIN(I)=2)  
C     INTERIOR  (MIN(I)=3)  
C     HIGH END  (MIN(I)=1)  
C     SET ISID=0 IF MULTIPLE TURNING POINTS  
C         ISID=1 IF SINGLE CLOSEST DISTANCE FROM SITE TO FAULT  
C         INTERIOR TO FAULT  
C         ISID=2 IF CLOSEST DISTANCE FROM SITE TO FAULT AT ONE END  
C         OF THE FAULT  
      DIMENSION DLP(20)  
      COMMON/LINPS/DISTL(24,26),DISQ(24,26),JSEG,JSEGM,  
     + XL(24,26),YP(24,26),COA(24,26),SIA(24,26)  
      COMMON/EXTRA/ISID,SHDIS,DIST(24),INEAR  
      COMMON /LINDIS/DLS(24),PERP(24),MIN(24),PERSQ(24)  
      SHDIS=1.E9  
      DO 10 II=1,JSEGM  
   10 DIST(II)=DISTL(II,JL)  
      I1=0  
      I2=0  
      I3=0  
      ISID=0  
      DO 20 I=1,JSEG  
      SLSQ=(X-XL(I,JL))**2+(Y-YP(I,JL))**2  
      IF(SLSQ.LT.SHDIS) SHDIS=SLSQ  
   20 CONTINUE  
      DO 50 I=1,JSEGM  
      XD=X-XL(I,JL)  
      YD=Y-YP(I,JL)  
      PERP(I)=-XD*SIA(I,JL)+YD*COA(I,JL)  
      DLS(I)=XD*COA(I,JL)+YD*SIA(I,JL)  
      PERSQ(I)=PERP(I)*PERP(I)  
      IF(DLS(I).LT.0) GO TO 30  
      IF(DLS(I).LE.DIST(I)) GO TO 40  
C      SHORTEST DISTANCE EXTERNAL TO SEGMENT  
      MIN(I)=1  
      I1=I1+1  
      DLP(I)=DLS(I)-DIST(I)  
      GO TO 50  
   30 MIN(I)=2  
      I2=I2+1  
      GO TO 50  
   40 MIN(I)=3  
      I3=I3+1  
      IF(PERSQ(I).LT.SHDIS) SHDIS=PERSQ(I)  
      DLP(I)=0.  
   50 CONTINUE  
      IF(I1.NE.JSEGM)  GO TO 90  
      IUP=JSEGM  
      ISID=2  
   60 IUH=IUP/2  
      IF(2*IUH.NE.IUP) DLS(IUH+1)=-DLP(IUH+1)  
      IF(IUP.EQ.1)  GO TO 80  
      J=IUP  
      DO 70 I=1,IUH  
      T=PERSQ(I)  
      PERSQ(I)=PERSQ(J)  
      PERSQ(J)=T  
      DLS(I)=-DLP(J)  
      DLS(J)=-DLP(I)  
      T=DIST(I)  
      DIST(I)=DIST(J)  
      MIN(I)=2  
      MIN(J)=2  
      DIST(J)=T  
   70 J=J-1  
   80 RETURN  
   90 IF(I2.NE.JSEGM)  GO TO 100  
      ISID=2  
      RETURN  
  100 IF(I3.GT.1) RETURN  
      IF(MIN(1).EQ.2) RETURN  
      ITURN=0  
      DO 110 K=1,JSEGM  
      IF(MIN(K).NE.1) GO TO 120  
      ITURN=ITURN+1  
  110 CONTINUE  
  120 IF(ITURN.NE.I1) RETURN  
      IF(I3.EQ.1 .AND. MIN(K).EQ.2) RETURN  
C   WE HAVE SINGLE TURNING POINT  
      ISID=1  
      INEAR=K-1  
      IF(MIN(K).NE.3) GO TO 140  
      INEAR=K  
C      ADJUST TO 2 SEP SEGMENTS  
      J=JSEG  
      DO 130 I=K,JSEGM  
      DLS(J)=DLS(J-1)  
      PERSQ(J)=PERSQ(J-1)  
      DIST(J)=DIST(J-1)  
  130 J=J-1  
      JSEGM=JSEG  
      JSEG=JSEG+1  
      DIST(K+1)=DIST(K+1)-DLS(K)  
      DIST(K)=DLS(K)  
      DLS(K+1)=0  
  140 IUP=INEAR  
      GO TO 60  
      END  
C **************************************************************  
      SUBROUTINE PBREAK(FM,AL,BL,SIGL,RLLS,PRLS,LEV,NRLS)  
      DIMENSION FM(12),PRLS(12),RLLS(10,12)  
      DIMENSION PMID(5),PRANG(5)  
      DATA PMID/1.575,.74,0.,-.74,-1.575/  
      DATA PRANG/.1151,.2295,.3108,.2295,.1151/  
      DATA NRL/5/  
C      EVALUATE AL+BL*FM(L)+PMID(I)*SIGL  
C     WHERE  1 <L <LEV     AND 1 < I < NRL  
C     PRANG PROBABILITY ASSOCIATED WITH JTH BREAK  
C     FOR EACH MAGNITUDE; COMPUTE NRL RUPTURE LENGTHS  
C      :::::::: MUST BE ORDERED IN DESCENDING ORDER--LARGEST BREAK  
C      ::::::::: LENGTH FIRST FOR EACH MAGNITUDE  
      DO 10 J=1,LEV  
      CON=AL + BL*FM(J)  
      DO 10 I=1,NRL  
      C=CON+PMID(I)*SIGL  
   10 RLLS(I,J)=10.**C  
      DO 20 I=1,NRL  
   20 PRLS(I)=PRANG(I)  
      NRLS=NRL  
      RETURN  
      END  
C *************************************************************  
      SUBROUTINE BBGAUS(X,GG)  
C   COMPUTES NORMAL PROBABILITY INTEGRAL GG FROM -(INFINITY) TO XX  
C    SETS GG=1 IF XX < -6;  GG=0  IF XX > +6  
C   USES APPROXIMATION HANDBOOK OF MATHEMATICAL FUNCTIONS-  
C   NBS APPLIED MATH SERIES 55--P299 7.1.26 FOR ERROR FUNCTION  
      AX=ABS(X)/1.4142136  
      IF(AX-4.2426408) 20,20,10  
   10 GG=0.  
      IF(X.LT.0) GG=+1.  
      RETURN  
   20 CONTINUE  
      D=1.+(((((4.30638E-5*AX+2.765672E-4)*AX+1.520143E-4  
     + )*AX+9.2705272E-3)*AX+4.2282012E-2)*AX+7.0523078E-2)*AX  
      D=D*D  
      D=D*D  
      D=D*D  
      GG=.5/(D*D)  
      IF(X) 30,30,40  
   30 GG=1.-GG  
   40 RETURN  
      END  
C ************************************************************  
      SUBROUTINE OUTSID(XNOT,YNOT,ISUB,R,ANGLE)  
      COMMON/INOUT/IC,ICS,IFAR,AZIMF,STSIZE,DUM1  
      COMMON/XYSAV/XSAV(2,50),YSAV(2,50),SAREA(50)  
       COMMON/XLYL/XL(4),YL(4),XR(4),YR(4), XC(4),YC(4)  
       COMMON/SLINP / AA(4,50),BB(4,50),CC(4,50),RTA(4,50),DIST(4,50)  
     +,DISQ(4,50)  
      COMMON/SLINDS/DLS(4),PERP(4),SL1(4),SLSQ(4),MIN(4),PERSQ(4)  
     +,SRSQ(4),DLP(4)  
      DIMENSION JSUB(3)  
C     SUBROUTINE FOR CALCULATING ANGLE WHEN SITE IS OUTSIDE  
C          (QUADRILATERAL) SOURCE AREA.  
C      R IS THE RADIAL DISTANCE FOR WHICH ANGLE IS SOUGHT  
C  
C     (XNOT,YNOT)=POINT OUTSIDE QUADRILATERAL SOURCE REGION ISUB  
C     R=RADIUS OF CIRCLE (OR RADIUS OF ANNULAR RING OF WIDTH DR)  
C     CENTERED AT (XNOT,YNOT)  
C     ISUB = INDEX IDENTIFYING QUADRILATERAL SOURCE REGION  
C  
C    THE AREA CONTAINED IN THE INTERSECTION OF THE REGION AND ANNULAR  
C     RING IS DETERMINED BY THE FRACTION OF THE RING WITHIN THE REGION.  
C            AREA = ANGLE X R X DR  
C     WHERE ANGLE = THE ANGLE (IN RADIANS) SUBTENDED BY THE  
C     PART OF THE ANNULAR RING CONTAINED WITHIN THE REGION.  
C  
C          (RC IS CLOSEST DISTANCE BETWEEN SITE AND SOURCE.)  
C          (RF IS FURTHEST DISTANCE BETWEEN SITE AND SOURCE)  
C       SUBROUTINE CSQDIS HAS COMPUTED DISTANCE TO VERTICES OF SUBREGION  
C       AND SHORTEST DISTANCE TO EACH SIDE  
C       ADAPTED FROM SUBROUTINE BY MCGUIRE  
C  
      DATA JSUB/2,3,1/  
      NPT=0  
      ANGLE=0.  
      SIGNAL=1.  
C        LOOP ON EACH SIDE  
      RSQ=R*R  
      DO 140 II=1,4  
      IF(MIN(II)-2) 10,40,70  
C     CLOSEST POINT IS XR(II),YR(II)  
C       AT MOST ONE INTERSECTION  
   10 IF(RSQ.GT.SLSQ(II)) GO TO 140  
      IF(RSQ.LT.SRSQ(II)) GO TO 140  
      D=(SQRT(RSQ-PERSQ(II))-DLP(II))/DIST(II,ISUB)  
   20 Y1=(YL(II)-YR(II))*D+YR(II)  
      X1=(XL(II)-XR(II))*D+XR(II)  
C  INTERSECTS IN RANGE  
C          DOES CIRCLE (RADIUS R) INTERSECT IT?  
C        STORE FIRST POINT  
   30 NPT=NPT+1  
      XC(NPT)=X1  
      YC(NPT)=Y1  
      GO TO 140  
C   CLOSEST POINT IS AT XL(II),YL(II)  
   40 IF(RSQ.LT.SLSQ(II)) GO TO 140  
      IF(RSQ.GT.SRSQ(II)) GO TO 140  
   50 D=(SQRT(RSQ-PERSQ(II))+DLS(II))/DIST(II,ISUB)  
   60 X1=XL(II)+(XR(II)-XL(II))*D  
      Y1=YL(II)+(YR(II)-YL(II))*D  
      GO TO 30  
   70 IF(RSQ.LT.PERSQ(II)) GO TO 140  
      IF(RSQ.LE.SLSQ(II)) GO TO 80  
      IF(RSQ.GT.SRSQ(II)) GO TO 140  
C   SINGLE INTERSECTION  
C     ON SIDE NEARER XR,YR  
      GO TO 50  
   80 IF(RSQ.GT.SRSQ(II)) GO TO 90  
C     TWO INTERSECTIONS ON THIS SIDE  
C    CAN COMPUTE ANGLE DIRECTLY WITHOUT DETERMINING COORDINATES  
      ARG=ABS(PERP(II))/R  
      AS=ACOS(ARG)  
      GO TO 100  
   90 D=(DLS(II)-SQRT(RSQ-PERSQ(II)) )/DIST(II,ISUB)  
      GO TO 60  
C    SINGLE INTERSECTION  
C        SEE IF THIS SIDE IS CLOSEST TO POINT, IF SO, TREAT SPECIALLY.  
  100 IF (II-ICS) 110,120,110  
C          BOTH POINTS ARE ON BOUNDARY, CALCULATE ANGLE BETWEN THEM.  
  110 SIGN=-1.  
      GO TO 130  
  120 SIGN=1.  
      SIGNAL=-1.  
  130 ANGLE=SIGN*2.*AS + ANGLE  
C        SEE IF SECOND POINT ONLY IS ON BOUNDARY  
  140 CONTINUE  
      IF(NPT.GT.0) GO TO 150  
      IF(SIGNAL) 310,320,320  
  150 GO TO (320,240,160,250),NPT  
C     THIS IS AN ERROR UNLESS RADIUS IS ON A VERTEX AND  
C      WAS COUNTED TWICE.  
  160 DO 170 I=1,3  
      J=JSUB(I)  
      IF(ABS(XC(I)-XC(J)) .GE. .01) GO TO 170  
      IF(ABS(YC(I)-YC(J)) .LE. .01) GO TO 220  
  170 CONTINUE  
C   CHECK FOR ONE OF THREE POINTS BEING A VERTEX  
      DO 210 I=1,4  
      DO 180 J=1,3  
      IF(ABS(XC(J)-XL(I)).GT. .001) GO TO 180  
      IF(ABS(YC(J)-YL(I)) .LE. .001) GO TO 190  
  180 CONTINUE  
      GO TO 210  
  190 IF(J-2) 200,200,230  
  200 XC(J)=XC(3)  
      YC(J)=YC(3)  
      GO TO 230  
  210 CONTINUE  
      GO TO 320  
  220 IF(I.NE.1) GO TO 230  
      XC(2)=XC(3)  
      YC(2)=YC(3)  
  230 NPT=2  
      GO TO 240  
  240 AD=SQRT((XC(1)-XC(2))*(XC(1)-XC(2))+(YC(1)-YC(2))*(YC(1)-YC(2)))  
      ANGLE=ANGLE + SIGNAL*2.*ASIN(AD/(2.*R))  
      GO TO 310  
C          FOUR INTERSECTION POINTS (EACH ON A DIFFERENT SIDE).  
C          DETERMINE ANGLE BY FINDING CLOSEST 2 INTERSECTIONS TO  
C          FARTHEST CORNER, CALCULATE ANGLE BETWEEN, AND ADD ANGLE  
C          BETWEEN OTHER TWO INTERSECTIONS.  
  250 DIST1=10000000.  
      I1=0  
      I2=0  
      I3=0  
      I4=0  
      DO 300 JJ=1,4  
      DISTN=(XL(IFAR)-XC(JJ))*(XL(IFAR)-XC(JJ))  
     +  +(YL(IFAR)-YC(JJ))*(YL(IFAR)-YC(JJ))  
      IF (DISTN-DIST1) 260,260,270  
  260 DIST2=DIST1  
      DIST1=DISTN  
      I4=I3  
      I3=I2  
      I2=I1  
      I1=JJ  
      GO TO 300  
  270 IF (DISTN-DIST2) 280,280,290  
  280 DIST2=DISTN  
      I4=I3  
      I3=I2  
      I2=JJ  
      GO TO 300  
  290 I4=I3  
      I3=JJ  
  300 CONTINUE  
C           CALCULATE ANGLE BETWEEN 2 CLOSEST POINTS TO FARTHEST CORNER.  
      AD=SQRT((XC(I1)-XC(I2))*(XC(I1)-XC(I2))  
     +  + (YC(I1)-YC(I2))*(YC(I1)-YC(I2)))  
      ANGLE=2.*ASIN(AD/(2.*R))  
C         CALCULATE ANGLE BETWEEN 2 POINTS FARTHEST FROM  
C         FARTHEST CORNER AND ADD TO PREVIOUS ANGLE.  
      AD=SQRT((XC(I3)-XC(I4))*(XC(I3)-XC(I4))  
     +  +(YC(I3)-YC(I4))*(YC(I3)-YC(I4)))  
      ANGLE=2.*ASIN(AD/(2.*R)) + ANGLE  
  310 CONTINUE  
C        COMPUTE RATE OF EARTHQUAKES IN THIS ANNULAR SOURCE  
      RETURN  
C        ERROR PRINTOUT  
  320 WRITE(16,330)ISUB,IC,NPT,XNOT,YNOT,(XL(I),YL(I), I=1,4),R,ANGLE,  
     +(XC(I),YC(I),I=1,4)  
  330 FORMAT(' ***** ERROR IN SUBROUTINE OUTSID. SOURCE NO.',I3,  
     +' DEBUG VALUES FOLLOW.....',/10X,2I5,5(/10X,4F14.6))  
  340 STOP 9999  
      END  
C **************************************************************  
      SUBROUTINE INSIDE(XNOT,YNOT,ISUB,R,PANGLE)  
      COMMON/XYAREA/XSAV(2,50),YSAV(2,50),SAREA(50)  
      COMMON/INOUT/IC,ICS,IFAR,AZIMF,STSIZE,STEPO  
      COMMON/SLINDS/DLS(4),PERP(4),SL1(4),SLSQ(4),MIN(4),PERSQ(4)  
     +,SRSQ(4),DLP(4)  
      COMMON/SLINP/AA(4,50),BB(4,50),CC(4,50),RTA(4,50),DIST(4,50),  
     + DISQ(4,50)  
      COMMON/XLYL/XL(4),YL(4),XR(4),YR(4),XC(4),YC(4)  
      DIMENSION JSUB(3)  
C  
C     (XMID,YMID)=POINT INSIDE QUADRILATERAL SOURCE REGION II  
C     R=RADIUS OF CIRCLE (OR RADIUS OF ANNULAR RING OF WIDTH DR)  
C     CENTERED AT (XMID,YMID)  
C     II = INDEX IDENTIFYING QUADRILATERAL SOURCE REGION  
C  
C    THE AREA CONTAINED IN THE INTERSECTION OF THE REGION AND ANNULAR  
C     RING IS DETERMINED BY THE FRACTION OF THE RING WITHIN THE REGION.  
C            AREA = PANGLE X R X DR  
C     WHERE PANGLE = THE ANGLE (IN RADIANS) SUBTENDED BY THE  
C     PART OF THE ANNULAR RING CONTAINED WITHIN THE REGION.  
C     SUBROUTINE INSID DETERMINES PANGLE.  
C  
C       ADAPTED FROM SUBROUTINE BY MCGUIRE  
      DATA PI,PI2/3.1415927,6.2831853/  
      DATA JSUB/2,3,1/  
      RSQ=R*R  
      NPT=0  
      ANGLE=0.  
C         LOOP ON EACH SIDE  
      DO 110 II=1,4  
      IF(MIN(II)-2) 10,40,70  
C     CLOSEST POINT IS XR(II),YR(II)  
C       AT MOST ONE INTERSECTION  
   10 IF(RSQ.GT.SLSQ(II)) GO TO 110  
      IF(RSQ.LT.SRSQ(II)) GO TO 110  
      D=(SQRT(RSQ-PERSQ(II))-DLP(II))/DIST(II,ISUB)  
   20 Y1=(YL(II)-YR(II))*D+YR(II)  
      X1=(XL(II)-XR(II))*D+XR(II)  
C  INTERSECTS IN RANGE  
C          DOES CIRCLE (RADIUS R) INTERSECT IT?  
C        STORE FIRST POINT  
   30 NPT=NPT+1  
      XC(NPT)=X1  
      YC(NPT)=Y1  
      GO TO 110  
C   CLOSEST POINT IS AT XL(II),YL(II)  
   40 IF(RSQ.LT.SLSQ(II)) GO TO 110  
      IF(RSQ.GT.SRSQ(II)) GO TO 110  
   50 D=(SQRT(RSQ-PERSQ(II))+DLS(II))/DIST(II,ISUB)  
   60 X1=XL(II)+(XR(II)-XL(II))*D  
      Y1=YL(II)+(YR(II)-YL(II))*D  
      GO TO 30  
   70 IF(RSQ.LT.PERSQ(II)) GO TO 110  
      IF(RSQ.LE.SLSQ(II)) GO TO 80  
      IF(RSQ.GT.SRSQ(II)) GO TO 110  
C   SINGLE INTERSECTION  
C     ON SIDE NEARER XR,YR  
      GO TO 50  
   80 IF(RSQ.GT.SRSQ(II)) GO TO 90  
C     TWO INTERSECTIONS ON THIS SIDE  
C    CAN COMPUTE ANGLE DIRECTLY WITHOUT DETERMINING COORDINATES  
      ARG=ABS(PERP(II))/R  
      AS=ACOS(ARG)  
      GO TO 100  
   90 D=(DLS(II)-SQRT(RSQ-PERSQ(II)))/DIST(II,ISUB)  
      GO TO 60  
C    SINGLE INTERSECTION  
C          BOTH POINTS ARE ON BOUNDARY, CALCULATE ANGLE BETWEN THEM.  
  100 ANGLE=2.*AS + ANGLE  
C        SEE IF SECOND POINT ONLY IS ON BOUNDARY  
  110 CONTINUE  
      IF (NPT) 570,120,140  
  120 IF (ANGLE-0.001) 570,130,130  
C        FOLLOWING IS FOR CASE OF NO SINGLE INTERSECTION POINTS;  
C        ANGLE IS 2 * PI - ANGLE CALCULATED SO FAR.  
  130 PANGLE=PI2-ANGLE  
      GO TO 560  
  140 GO TO (570,230,150,500),NPT  
C     THIS IS AN ERROR UNLESS RADIUS IS ON A VERTEX AND  
C      WAS COUNTED TWICE.  
  150 DO 160 I=1,3  
      J=JSUB(I)  
      IF(ABS(XC(I)-XC(J)) .GE. .01) GO TO 160  
      IF(ABS(YC(I)-YC(J)) .LE. .01) GO TO 210  
  160 CONTINUE  
C   CHECK FOR ONE OF THREE POINTS BEING A VERTEX  
      DO 200 I=1,4  
      DO 170 J=1,3  
      IF(ABS(XC(J)-XL(I)).LE. .001) GO TO 170  
      IF(ABS(YC(J)-YL(I)) .GT. .001) GO TO 180  
  170 CONTINUE  
      GO TO 200  
  180 IF(J-2) 190,190,220  
  190 XC(J)=XC(3)  
      YC(J)=YC(3)  
      GO TO 220  
  200 CONTINUE  
      GO TO 570  
  210 IF(I.NE.1) GO TO 220  
      XC(2)=XC(3)  
      YC(2)=YC(3)  
  220 NPT=2  
      GO TO 230  
C         2 INTERSECTION POINTS; DETERMINE AZIMUTHS.  
  230 IF (XC(1)-XNOT-R) 260,250,240  
  240 IF (XC(1)-XNOT-R-0.001) 250,250,570  
  250 AZIM1=0.0  
      GO TO 300  
  260 IF (XC(1)-XNOT+R) 270,280,290  
  270 IF (XC(1)-XNOT+R+0.001) 570,280,280  
  280 AZIM1=PI  
      GO TO 320  
  290 AZIM1=ACOS((XC(1)-XNOT)/R)  
  300 IF (YC(1)-YNOT) 310,320,320  
  310 AZIM1=PI2  - AZIM1  
  320 IF (XC(2)-XNOT-R) 350,340,330  
  330 IF (XC(2)-XNOT-R-0.001) 340,340,570  
  340 AZIM2=0.0  
      GO TO 390  
  350 IF (XC(2)-XNOT+R) 360,370,380  
  360 IF (XC(2)-XNOT+R+0.001) 570,370,370  
  370 AZIM2=PI  
      GO TO 410  
  380 AZIM2=ACOS((XC(2)-XNOT)/R)  
  390 IF (YC(2)-YNOT) 400,410,410  
  400 AZIM2=PI2 -AZIM2  
  410 PANGLE=AZIM2-AZIM1  
      IF (PANGLE) 420,570,460  
  420 IF (AZIM1-AZIMF) 430,570,440  
  430 PANGLE=PI2 +PANGLE -ANGLE  
      GO TO 560  
  440 IF (AZIMF-AZIM2) 430,570,450  
  450 PANGLE=-PANGLE-ANGLE  
      GO TO 560  
  460 IF (AZIM2-AZIMF) 470,570,480  
  470 PANGLE=PI2 -PANGLE -ANGLE  
      GO TO 560  
  480 IF (AZIMF-AZIM1) 470,570,490  
  490 PANGLE=PANGLE-ANGLE  
      GO TO 560  
C        FOUR INTERSECTION POINTS (EACH ON A DIFFERENT SIDE).  
C        DETERMINE ANGLE BY FINDING CLOSEST 2 INTERSECTIONS TO  
C        FARTHEST CORNER, CALCULATE ANGLE BETWEN, AND ADD ANGLE  
C        BETWEEN OTHER TWO INTERSECTIONS.  
  500 DIST1=10000000.  
      I1=0  
      I2=0  
      I3=0  
      I4=0  
      DO 550 JJ=1,4  
      DISTN=(XL(IFAR)-XC(JJ))*(XL(IFAR)-XC(JJ))  
     +   +(YL(IFAR)-YC(JJ))*(YL(IFAR)-YC(JJ))  
      IF (DISTN-DIST1) 510,510,520  
  510 DIST2=DIST1  
      DIST1=DISTN  
      I4=I3  
      I3=I2  
      I2=I1  
      I1=JJ  
      GO TO 550  
  520 IF(DISTN-DIST2) 530,530,540  
  530 DIST2=DISTN  
      I4=I3  
      I3=I2  
      I2=JJ  
      GO TO 550  
  540 I4=I3  
      I3=JJ  
  550 CONTINUE  
C        CALCULATE ANGLE BETWEEN 2 CLOSEST POINTS TO FARTHEST CORNER  
      AD=SQRT((XC(I1)-XC(I2))*(XC(I1)-XC(I2))  
     +  + (YC(I1)-YC(I2))*(YC(I1)-YC(I2)))  
      PANGLE=2.*ASIN(AD/(2.*R))  
C         CALCULATE ANGLE BETWEEN 2 FARTHEST POINTS FROM  
C         FARTHEST CORNER AND ADD TO PREVIOUS ANGLE.  
      AD=SQRT((XC(I3)-XC(I4))*(XC(I3)-XC(I4))  
     + + (YC(I3)-YC(I4))*(YC(I3)-YC(I4)))  
      PANGLE=2.*ASIN(AD/(2.*R))+PANGLE  
C       ANGLE FOR THIS RADIUS IS NOW KNOWN, CALCULATE RISK  
  560 RETURN  
C     ANAREA=PANGLE*R*STSIZE  
C          ERROR PRINTOUT  
  570 WRITE (16,580) ISUB,IFAR,NPT,XNOT,YNOT,(XL(I),YL(I), I=1,4),R,  
     +PANGLE,(XC(I),YC(I),I=1,4)  
  580 FORMAT (' ***** ERROR IN SUBROUTINE INSIDE. SOURCE NO.',  
     + I3,' DEBUG VALUES FOLLOW......',/10X,2I10,10(/10X,2F12.6))  
  590 STOP 0000  
      END  
C************************************************************  
      SUBROUTINE SPREAD(REG,JLO,LL,TOTAC,DMID)  
C     MAGNITUDE SMOOTHER FOR FAULT RUPTURES:  
C     TOTAC ACCELERATION OCCURRENCES CALCULATED FOR RUPTURES OF    
C     MAGNITUDE FM(LL) AT DISTANCE DMID FROM SITE   
C     ARE "SPREAD" TO ACCELERATION LEVELS CORRESPONDING  
C     TO MAGNITUDES IN THE RANGE   
C     FM(LL)-DELTA/2 < FM(LL) < FM(LL)+DELTA/2  
C     [WHERE FM(LL-1)=FM(LL)-DELTA].  
C     EARTHQUAKE OCCURRENCES FOLLOW A GUTENBERG-RICHTER  
C     MAGNITUDE-FREQUENCY RELATIONSHIP, CALCULATED FROM NUMBER    
C     OF EARTHQUAKES INPUT AT 2 SUCCESSIVE MAGNITUDES.  
      COMMON/MAGDIS/JENT,MDIS  
      COMMON/RTB/RTAB(20)  
      DIMENSION REG(106)  
      COMMON/ACCEL/GM(25),EXDIF(101),ATAH(20,25),ACLIM(2)  
      COMMON/WDS/MAX,MAXP,MAXSP  
      COMMON/QUAD/MAXQ,AC(105),DUMLOG,ACLOG(105)  
   10 CONTINUE  
      IF(DMID.EQ.-1.) GO TO 60  
      DO 20 I=2,MDIS  
      IF(DMID.LE.RTAB(I)) GO TO 40  
   20 CONTINUE  
C  DISTANCE EXCEEDS TABLE--WE SHOULD NOT EVEN BE HERE  
      WRITE(16,30) DMID  
   30 FORMAT(' IN SPREAD, DMID=',E12.5,' TOO LARGE-SHOULD NOT BE HERE')  
      STOP 1111  
   40 FR=(RTAB(I)-DMID)/(RTAB(I)-RTAB(I-1))  
      ILIM=1  
      LP=LL+1  
      DO 50 LM=LL,LP  
      ACLIM(ILIM)=ATAH(I,LM)-FR*(ATAH(I,LM)-ATAH(I-1,LM))  
   50 ILIM=2  
   60 ACDIF=ACLIM(2)-ACLIM(1)  
      IF(ACDIF.NE.0.) GO TO 90  
      JBOT=JLO+1  
   70 IF(ACLOG(JBOT).LE.ACLIM(1)) GO TO 80  
      JBOT=JBOT-1  
      IF(JBOT.GE.1) GO TO 70  
   80 JUP=JBOT+1  
      REG(JUP)=REG(JUP)+TOTAC  
      RETURN  
   90 ADD=0.  
      JBOT=JLO+1  
  100 IF(ACLOG(JBOT).LE.ACLIM(1)) GO TO 110  
      JBOT=JBOT-1  
      IF(JBOT.GE.1) GO TO 100  
C    WE ARE ALOWER ACCEL LEVEL--FOR LOWEST MAG OF RANGE  
  110 ACLO=EXDIF(1)  
      JUP=JBOT+1  
  120 UPL=ACLOG(JUP)  
      IF(UPL.GT.ACLIM(2)) UPL=ACLIM(2)  
      FR=(UPL-ACLIM(1))/ACDIF  
      IACHI=100.*FR+1.00001  
      QUAN=(+EXDIF(IACHI)-ACLO)*TOTAC  
      ADD=ADD+QUAN  
      REG(JUP)=REG(JUP)+QUAN  
      IF(ACLIM(2).EQ.UPL) GO TO 130  
      ACLO=EXDIF(IACHI)  
      JUP=JUP+1  
      IF(JUP.LE.MAXP) GO TO 120  
      WRITE(16,125)  
  125 FORMAT(' SPREAD ROUTINE NEEDS HIGHER ACCELERATION LEVEL;',  
     1/' REWRITE BOX OR INCREASE SCALE FACTOR')  
      STOP 2222  
  130 CONTINUE  
      RETURN  
      END  
C***********************************************************  
      SUBROUTINE OUT(REG,NAF,XOUTS,YOUTS,SD)  
      COMMON/TIMS/FTIM(20),JTIM(20),NTIMS,NWT,IPRINT  
      COMMON/RDIS/RDIS  
      DIMENSION QP(140),SOL(20),SOLS(20)  
      COMMON/QUAD/MAXQ,AC(105),DUMLOG,ACLOG(105)  
      DIMENSION REG(106)  
      COMMON/EXT/PROB,EX,EXL  
      COMMON/WDS/MAX,MAXP,MAXSP  
      DIMENSION REGS(106),CDFS(105),CDF(105)  
      IF(IPRINT.LE.2) WRITE(16,10) XOUTS,YOUTS,RDIS,SD  
   10 FORMAT(' SITE AT LONG ',F8.3,', LAT ',F8.3,  
     +/' SHORTEST DIST TO FAULT=',F9.3,' KM'/10X,  
     +'ZERO ATTENUATION VARIABILITY',18X,'VARIABILITY IN ATTEN, SIGMA=',  
     + F5.2/2( '    G.M.   OCC/YR    EXC/YR  R(EVENTS) R(YRS) '))  
      DO 20 L=1,MAXSP  
   20 REGS(L)=0  
   30 SD6=4.4*SD  
      KLS=1  
      DO 70 L=1,MAX  
      IF(REG(L+1).EQ.0) GO TO 70  
      ASAV=(ACLOG(L)+ACLOG(L+1))/2.  
      KL=KLS  
   40 IF(ACLOG(KL)-ASAV.GE.-SD6) GO TO 50  
      KL=KL+1  
      IF(KL.LE.MAX) GO TO 40  
      GO TO 70  
   50 KLS=KL  
      W=(ACLOG(KL)-ASAV)/SD  
      CALL BBGAUS(W,G1)  
      IF(KL.EQ.1) REGS(1)=REGS(1)+(1.-G1)*REG(L+1)  
   60 KL=KL+1  
      WH=(ACLOG(KL)-ASAV)/SD  
      CALL BBGAUS(WH,G2)  
      REGS(KL)=REGS(KL)+(G1-G2)*REG(L+1)  
      IF(WH.GE.4.4) GO TO 70  
      IF(KL.GE.MAXSP) GO TO 70  
      G1=G2  
      GO TO 60  
   70 CONTINUE  
C  WE ARE REALLY NOT INTERESTED IN 1ST 4 ACCELERATION BOXES BUT USED  
C  THEM FOR COMPUTATION OF VARIABILITY IN ACCELERATION--CORRECT SO  
C  BOX 5 ACCUMULATES ALL ACCELERATIONS BELOW AC(5)  
C  AC(5) IS THE FIRST VALUE PRINTED  
   80 CONTINUE  
      REGS(1)=REGS(1)+REG(1)  
      REGSAV=REG(5)  
      REGSSV=REGS(5)  
      DO 90 I=1,4  
      REGS(5)=REGS(5)+REGS(I)  
   90 REG(5)=REG(5)+REG(I)  
      CDFS(MAXSP)=0.  
      CDF(MAXP)=0.  
      MAXQ=MAXP  
      K=MAX  
      DO 100 I=5,MAX  
      CDF(K)=CDF(K+1)+REG(K+1)  
  100 K=K-1  
      MM=MAXSP-1  
      K=MM  
      DO 110 I=5,MM  
      CDFS(K)=CDFS(K+1)+REGS(K+1)  
  110 K=K-1  
      IF((CDFS(5).NE.0.0).AND.(CDF(5).NE.0.0)) GO TO 140  
      IF(IPRINT.GE.2) WRITE(16,120)  
  120 FORMAT(' NO ACCELERATION EVENTS ACCUMULATED. STATISTICS CALC.  
     +BYPASSED')  
      DO 130 IER=1,NTIMS  
      SOL(IER)=0.0  
  130 SOLS(IER)=0.  
      GO TO 380  
  140 CONTINUE  
C  
C  IF ACCELERATIONS DO NOT EXCEED AC(5), THE FIRST ACCELERATION  
C  OF INTEREST, SKIP STATISTICS CALCULATION TO AVOID DIVIDING BY  
C  ZERO OR UPSETTING INTERPOLATION ROUTINES.  
C  
      CNUMS=CDFS(5)+REGS(5)  
      CNUM=CDF(5)+REG(5)  
      YRNCNM=1./CNUM  
      NREP=0  
      IDONE=0  
      IF(IPRINT.EQ.3) GO TO 330  
      DO 300 I=5,MAXSP  
      IF(I.GT.MAX) GO TO 150  
      IF(CDF(I).EQ.0.0) GO TO 170  
      IF(REG(I).NE.0) GO TO 160  
  150 IF(REGS(I).EQ.0.) GO TO 190  
C  
C   COMPUTE RETURN PERIOD IN NUMBER OF EVENTS AND NUMBER OF YEARS  
C   RETURN PERIOD IN EVENTS = AVERAGE NUMBER OF EARTHQUAKES NEEDED  
C   TO PRODUCE AN ACCELERATION EXCEEDING A  
C      R(EVENTS)=(YEARLY EARTHQUAKES)/(YEARLY EXCEEDANCES OF A)  
C   RETURN PERIOD IN YEARS = AVERAGE TIME BETWEEN EARTHQUAKES  
C   WHICH CAUSE ACCELERATION A TO BE EXCEEDED  
C      R(YRS)=1/(YEARLY EXCEEDANCES OF A)  
C  
  160 IF(I.LE.MAX) RETEV=CNUM/CDF(I)  
      RETYR=RETEV*YRNCNM  
C  
C   COMPUTE ACCELERATION WHICH HAS PROBABILITY PROB OF NOT BEING  
C   EXCEEDED DURING T YEARS.  THIS IS GIVEN BY THE VALUE OF A  
C   FOR WHICH  
C      PROB = EXP(-T * NUMBER OF EXCEEDANCES OF A PER YEAR)  
C  
      GO TO 180  
  170 RETEV=99999.9  
      RETYR=99999.9  
  180 IF(CDFS(I).EQ.0.) GO TO 190  
      RETEVS=CNUMS/CDFS(I)  
      RETYRS=RETEVS/CNUMS  
      GO TO 200  
  190 RETEVS=99999.9  
      RETYRS=99999.9  
      IF(CDF(I).NE.0.) GO TO 200  
      IDONE=1  
  200 CONTINUE  
      QP(NREP+1)=AC(I)  
      IF(I.LE.MAX) GO TO 210  
      QP(NREP+2)=0  
      QP(NREP+3)=0  
      RETEV=99999.9  
      RETYR=99999.9  
      GO TO 220  
  210 QP(NREP+2)=REG(I)  
      QP(NREP+3)=CDF(I)  
  220 IF(RETEV.GE.100000.) RETEV=99999.9  
      IF(RETYR.GE.100000.) RETYR=99999.9  
      QP(NREP+4)=RETEV  
      QP(NREP+5)=RETYR  
      QP(NREP+6)=AC(I)  
      QP(NREP+7)=REGS(I)  
      QP(NREP+8)=CDFS(I)  
      IF(RETEVS.GE.100000.) RETEVS=99999.9  
      IF(RETYRS.GE.100000.) RETYRS=99999.9  
      QP(NREP+9)=RETEVS  
      QP(NREP+10)=RETYRS  
      IF(NREP.NE.130) GO TO 260  
      IF(NAF.LE.3) GO TO 230  
      WRITE(16,280) QP  
      GO TO 240  
  230 WRITE (16,270) QP  
  240 CONTINUE  
      NREP=0  
  250 FORMAT(1H1)  
      IF(IDONE.EQ.1) GO TO 330  
      GO TO 300  
  260 NREP=NREP+10  
  270 FORMAT(1H ,F8.2,2F9.5,2F8.1,F12.2,2F9.5,2F8.1)  
  280 FORMAT(1H ,F8.4,2F9.5,2F8.1,F12.4,2F9.5,2F8.1)  
      IF(RETEV.EQ.99999.9 .AND. RETEVS.EQ.99999.9) GO TO 310  
  300 CONTINUE  
  310 IF(NREP.EQ.0) GO TO  330  
      IF(NAF.LE.3) GO TO 320  
      WRITE(16,280) (QP(LL),LL=1,NREP)  
      GO TO 330  
  320 WRITE(16,270) (QP(LL),LL=1,NREP)  
  330 IF (IPRINT.GT.2) GO TO 350  
      WRITE(16,340) CNUM,CNUMS,SD  
  340 FORMAT(2('   TOTAL YEARLY EVENTS ',F10.5,12X)  
     +//10X,'ZERO ATTENUATION VARIABILITY',18X,  
     + 'VARIABILITY IN ATTEN, SIGMA=',F4.2)  
C  
C   COMPUTE ACCELERATION WHICH HAS PROBABILITY PROB OF NOT BEING  
C   EXCEEDED DURING T YEARS.  THIS IS GIVEN BY THE VALUE OF A  
C   FOR WHICH  
C      PROB = EXP(-T * NUMBER OF EXCEEDANCES OF A PER YEAR)  
C  
  350 REG(5)=REGSAV  
      REGS(5)=REGSSV  
      DO 360 JV=1,NTIMS  
      MAXQ=MAX  
      CALL LININT(REG,FTIM(JV),SOL(JV))  
      MAXQ=MAXSP  
      CALL LININT(REGS,FTIM(JV),SOLS(JV))  
      IF(IPRINT.LE.2) WRITE(16,370)PROB,SOL(JV),JTIM(JV),SOLS(JV),  
     +JTIM(JV)  
  360 CONTINUE  
  370 FORMAT(F10.3,' EXT PROB =',F7.3,' FOR ',I5,' YEARS',19X,  
     + F7.3,' FOR ',I4,' YEARS')  
  380 RAT=0.0  
      IF(SOL(1).NE.0.0) RAT=SOL(NTIMS)/SOL(1)  
      RATSD=0  
      IF(SOLS(1).NE.0) RATSD=SOLS(NTIMS)/SOLS(1)  
      IF(IPRINT.LE.2)WRITE(16,390)JTIM(NTIMS),PROB,JTIM(1),RAT, RATSD  
      IF(IPRINT.GE.2) WRITE(2) XOUTS,YOUTS,(SOL(JT),JT=1,NTIMS),  
     +(SOLS(JT),JT=1,NTIMS)  
  390 FORMAT('   RATIO',I5,' YR',F6.3,' EXTREME VALUE TO',I5,' YR VAL  
     +=',F7.2,7X,F7.2)  
      RETURN  
      END  
